#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Prevent Bullet Points from Triggering False Positive Segmentation """


from lingpatlab.baseblock import BaseObject


class BulletPointCleaner(BaseObject):
    """ Prevent Bullet Points from Triggering False Positive Segmentation """

    def __init__(self):
        """ Change Log

        Created:
            30-Sept-2021
            craigtrim@gmail.com
            *   created
        Updated:
            19-Oct-2022
            craigtrim@gmail.com
            *   clean up for segment_text_3_test.py
        Updated:
            27-Mar-2024
            craigtrim@gmail.com
            *   migrated out of modai in pursuit of
                https://github.com/craigtrim/datapipe-apis/issues/72
        """
        BaseObject.__init__(self, __name__)

    @staticmethod
    def process(input_text: str) -> str:
        """
        Purpose:
            prevent numbered bullet points from triggering sentence detection
        :param input_text:
            any input text
        :return:
            preprocessed input text
        """
        if input_text.startswith("-"):
            input_text = input_text[1:]  # segment_text_3_test.py

        if "  " in input_text:
            input_text = input_text.replace("  ", " ")

        # the replacement routine above leaves double '..' in the text
        # this replacement will solve that
        while ".." in input_text:
            input_text = input_text.replace("..", ".")

        while ". -" in input_text:  # segment_text_3_test.py
            input_text = input_text.replace(". -", ". ")

        while ". . " in input_text:
            input_text = input_text.replace(". . ", ".")

        while '  ' in input_text:
            input_text = input_text.replace('  ', ' ')

        return input_text



# !/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Facade to find Stopwords Data on Disk """


from lingpatlab.baseblock import BaseObject
from lingpatlab.tokenizer.dto import stopwords


class StopwordFinder(BaseObject):
    """ Facade to find Stopwords Data on Disk """

    def __init__(self):
        """
        Created:
            25-Aug-2022
            craigtrim@gmail.com
            *   in pursuit of
                https://github.com/grafflr/graffl-core/issues/120
        """
        BaseObject.__init__(self, __name__)

    def exists(self,
               input_text: str) -> bool:
        input_text = input_text.lower().strip()
        return input_text in stopwords




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_o_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.194957'}

wordnet_terms_o = [
    'oaf',
    'oafish',
    'oahu',
    'oak',
    'oaken',
    'oakland',
    'oakley',
    'oaks',
    'oakum',
    'oar',
    'oarfish',
    'oarlock',
    'oars',
    'oarsman',
    'oarsmanship',
    'oarsmen',
    'oarswoman',
    'oas',
    'oasis',
    'oast',
    'oat',
    'oatcake',
    'oaten',
    'oates',
    'oath',
    'oatmeal',
    'oats',
    'oaxaca',
    'ob',
    'obadiah',
    'obama',
    'obbligato',
    'obduracy',
    'obdurate',
    'obeah',
    'obeche',
    'obechi',
    'obedience',
    'obedient',
    'obeisance',
    'obelion',
    'obelisk',
    'oberson',
    'obese',
    'obesity',
    'obey',
    'obeyed',
    'obeying',
    'obeys',
    'obfuscate',
    'obfuscation',
    'obi',
    'obiism',
    'obit',
    'obituary',
    'object',
    'objected',
    'objectification',
    'objectifies',
    'objectify',
    'objecting',
    'objection',
    'objectionable',
    'objectionableness',
    'objections',
    'objective',
    'objectively',
    'objectiveness',
    'objectives',
    'objectivity',
    'objector',
    'objects',
    'objet',
    'objets',
    'objurgate',
    'objurgation',
    'oblanceolate',
    'oblate',
    'oblateness',
    'oblation',
    'obligate',
    'obligated',
    'obligation',
    'obligational',
    'obligations',
    'obligato',
    'obligatory',
    'oblige',
    'obliged',
    'obliger',
    'obliging',
    'obligingness',
    'oblique',
    'obliquely',
    'obliqueness',
    'obliquity',
    'obliterable',
    'obliterate',
    'obliterated',
    'obliteration',
    'obliterator',
    'oblivion',
    'oblivious',
    'obliviousness',
    'oblong',
    'oblongata',
    'oblongness',
    'oblongs',
    'obloquy',
    'obnoxious',
    'obnoxiousness',
    'obnubilate',
    'oboe',
    'oboist',
    'obolus',
    'obovate',
    'obscene',
    'obscenities',
    'obscenity',
    'obscurantism',
    'obscurantist',
    'obscure',
    'obscured',
    'obscurely',
    'obscureness',
    'obscures',
    'obscuring',
    'obscurity',
    'obsequious',
    'obsequiously',
    'obsequiousness',
    'obsequy',
    'observable',
    'observance',
    'observances',
    'observant',
    'observation',
    'observational',
    'observations',
    'observatory',
    'observe',
    'observed',
    'observer',
    'observers',
    'observes',
    'observing',
    'obsess',
    'obsessed',
    'obsessing',
    'obsession',
    'obsessional',
    'obsessions',
    'obsessive',
    'obsessiveness',
    'obsessivity',
    'obsidian',
    'obsolesce',
    'obsolescence',
    'obsolescent',
    'obsolete',
    'obsoleteness',
    'obstacle',
    'obstacles',
    'obstetric',
    'obstetrical',
    'obstetrician',
    'obstetricians',
    'obstetrics',
    'obstinacy',
    'obstinance',
    'obstinate',
    'obstinately',
    'obstinates',
    'obstipate',
    'obstipation',
    'obstreperous',
    'obstreperousness',
    'obstruct',
    'obstructed',
    'obstructer',
    'obstructing',
    'obstruction',
    'obstructionism',
    'obstructionist',
    'obstructions',
    'obstructive',
    'obstructor',
    'obstructs',
    'obstruent',
    'obtain',
    'obtainable',
    'obtained',
    'obtaining',
    'obtainment',
    'obtains',
    'obtention',
    'obtrude',
    'obtrusive',
    'obtrusively',
    'obtrusiveness',
    'obtund',
    'obturate',
    'obturator',
    'obtuse',
    'obtuseness',
    'obtusifolium',
    'obverse',
    'obviate',
    'obviation',
    'obvious',
    'obviously',
    'obviousness',
    'oca',
    'ocarina',
    'occam',
    'occasion',
    'occasional',
    'occasionally',
    'occasioned',
    'occasions',
    'occident',
    'occidental',
    'occidentalis',
    'occidentalise',
    'occidentalism',
    'occidentalize',
    'occipital',
    'occipitomastoid',
    'occiput',
    'occitan',
    'occlude',
    'occluded',
    'occlusion',
    'occlusive',
    'occult',
    'occultation',
    'occulted',
    'occulting',
    'occultism',
    'occultist',
    'occults',
    'occupancy',
    'occupant',
    'occupants',
    'occupation',
    'occupational',
    'occupations',
    'occupied',
    'occupier',
    'occupies',
    'occupy',
    'occupying',
    'occur',
    'occurred',
    'occurrence',
    'occurrences',
    'occurrent',
    'occurring',
    'occurs',
    'ocean',
    'oceanaut',
    'oceanfront',
    'oceangoing',
    'oceania',
    'oceanic',
    'oceanica',
    'oceanid',
    'oceanites',
    'oceanographer',
    'oceanography',
    'oceanology',
    'oceans',
    'oceanus',
    'ocellated',
    'ocelli',
    'ocellus',
    'ocelot',
    'ocher',
    'ochlocracy',
    'ochna',
    'ochnaceae',
    'ochoa',
    'ochotona',
    'ochotonidae',
    'ochre',
    'ochroma',
    'ochronosis',
    'ochs',
    'ocimum',
    'ockham',
    'oconee',
    'ocotillo',
    'oct',
    'octad',
    'octagon',
    'octagonal',
    'octahedron',
    'octal',
    'octameter',
    'octane',
    'octangular',
    'octans',
    'octant',
    'octave',
    'octavian',
    'octavo',
    'octet',
    'octette',
    'octillion',
    'october',
    'octoberfest',
    'octogenarian',
    'octonary',
    'octopod',
    'octopoda',
    'octopodidae',
    'octopus',
    'octopuses',
    'octoroon',
    'octosyllabic',
    'octosyllable',
    'octroi',
    'octuple',
    'ocular',
    'oculism',
    'oculist',
    'oculists',
    'oculomotor',
    'oculus',
    'ocyurus',
    'od',
    'odalisque',
    'odd',
    'oddball',
    'oddish',
    'oddity',
    'oddly',
    'oddment',
    'oddments',
    'oddness',
    'odds',
    'ode',
    'oder',
    'odes',
    'odesa',
    'odessa',
    'odets',
    'odin',
    'odious',
    'odiousness',
    'odist',
    'odium',
    'odo',
    'odoacer',
    'odobenidae',
    'odobenus',
    'odocoileus',
    'odometer',
    'odonata',
    'odonate',
    'odontalgia',
    'odontaspididae',
    'odontaspis',
    'odontiasis',
    'odontoceti',
    'odontoglossum',
    'odontology',
    'odontophorus',
    'odor',
    'odoriferous',
    'odorize',
    'odorless',
    'odorous',
    'odors',
    'odour',
    'odourise',
    'odourless',
    'odovacar',
    'odovakar',
    'odynophagia',
    'odysseus',
    'odyssey',
    'oecanthus',
    'oecumenic',
    'oecumenical',
    'oecumenism',
    'oed',
    'oedema',
    'oedipus',
    'oedogoniaceae',
    'oedogoniales',
    'oedogonium',
    'oenanthe',
    'oengus',
    'oenologist',
    'oenology',
    'oenomel',
    'oenophile',
    'oenothera',
    'oersted',
    'oesophagitis',
    'oesophagoscope',
    'oesophagus',
    'oesterreich',
    'oestradiol',
    'oestral',
    'oestridae',
    'oestriol',
    'oestrogen',
    'oestrone',
    'oestrus',
    'oeuvre',
    'of',
    'off',
    'offal',
    'offbeat',
    'offenbach',
    'offence',
    'offenceless',
    'offences',
    'offend',
    'offended',
    'offender',
    'offenders',
    'offending',
    'offends',
    'offense',
    'offenseless',
    'offenses',
    'offensive',
    'offensively',
    'offensiveness',
    'offer',
    'offered',
    'offerer',
    'offering',
    'offerings',
    'offeror',
    'offers',
    'offertory',
    'offhand',
    'offhanded',
    'office',
    'officeholder',
    'officer',
    'officers',
    'offices',
    'official',
    'officialdom',
    'officialese',
    'officialise',
    'officialize',
    'officialized',
    'officially',
    'officials',
    'officiant',
    'officiate',
    'officiated',
    'officiates',
    'officiating',
    'officiation',
    'officio',
    'officious',
    'officiousness',
    'offing',
    'offish',
    'offload',
    'offprint',
    'offsaddle',
    'offset',
    'offsets',
    'offsetting',
    'offshoot',
    'offshore',
    'offside',
    'offsides',
    'offspring',
    'offstage',
    'ofo',
    'oft',
    'often',
    'oftenness',
    'og',
    'ogalala',
    'ogcocephalidae',
    'ogden',
    'ogdoad',
    'ogee',
    'ogive',
    'oglala',
    'ogle',
    'ogler',
    'ogre',
    'ogress',
    'oh',
    'ohio',
    'ohioan',
    'ohm',
    'ohmage',
    'ohmic',
    'ohmmeter',
    'ohms',
    'oig',
    'oil',
    'oilbird',
    'oilbirds',
    'oilcan',
    'oilcloth',
    'oiled',
    'oiler',
    'oilfield',
    'oilfish',
    'oiliness',
    'oilman',
    'oilpaper',
    'oilrig',
    'oils',
    'oilseed',
    'oilskin',
    'oilstone',
    'oilstove',
    'oily',
    'oink',
    'ointment',
    'ointments',
    'oireachtas',
    'ois',
    'ojibwa',
    'ojibway',
    'ok',
    'oka',
    'okapi',
    'okapia',
    'okapis',
    'okay',
    'okeechobee',
    'okeh',
    'oken',
    'okenfuss',
    'okey',
    'okhotsk',
    'okinawa',
    'oklahoma',
    'oklahoman',
    'okra',
    'oktoberfest',
    'ola',
    'old',
    'olden',
    'oldenburg',
    'older',
    'oldest',
    'oldfield',
    'oldie',
    'oldish',
    'oldline',
    'oldness',
    'oldster',
    'oldtimer',
    'oldwench',
    'oldwife',
    'olea',
    'oleaceae',
    'oleaceous',
    'oleaginous',
    'oleaginousness',
    'oleales',
    'oleander',
    'oleandra',
    'oleandraceae',
    'olearia',
    'oleaster',
    'olecranon',
    'oled',
    'olefin',
    'olefine',
    'oleic',
    'olein',
    'oleo',
    'oleomargarine',
    'oleophilic',
    'oleophobic',
    'oleoresin',
    'oleoresins',
    'oleracea',
    'olfaction',
    'olfactive',
    'olfactory',
    'olfersia',
    'olibanum',
    'oligarch',
    'oligarchic',
    'oligarchical',
    'oligarchy',
    'oligo',
    'oligocene',
    'oligochaeta',
    'oligochaete',
    'oligoclase',
    'oligodactyly',
    'oligodendria',
    'oligodendrocyte',
    'oligodendroglia',
    'oligodontia',
    'oligomenorrhea',
    'oligonucleotide',
    'oligoplites',
    'oligopoly',
    'oligoporus',
    'oligosaccharide',
    'oligospermia',
    'oliguria',
    'olimbos',
    'olive',
    'olivelike',
    'olivenite',
    'oliver',
    'olives',
    'olivier',
    'olivine',
    'olla',
    'ollari',
    'olm',
    'olmec',
    'olmsted',
    'ology',
    'olympia',
    'olympiad',
    'olympian',
    'olympic',
    'olympics',
    'olympus',
    'omaha',
    'oman',
    'omani',
    'omar',
    'omasum',
    'omayyad',
    'omb',
    'ombu',
    'ombudsman',
    'omdurman',
    'omega',
    'omelet',
    'omelets',
    'omelette',
    'omen',
    'omens',
    'omentum',
    'omeprazole',
    'omerta',
    'omicron',
    'ominous',
    'ominously',
    'omissible',
    'omission',
    'omissions',
    'omissive',
    'omit',
    'omits',
    'omitted',
    'omitting',
    'omiya',
    'ommastrephes',
    'ommatidium',
    'ommiad',
    'omnibus',
    'omnidirectional',
    'omnifarious',
    'omnipotence',
    'omnipotent',
    'omnipresence',
    'omnipresent',
    'omnirange',
    'omniscience',
    'omniscient',
    'omnivore',
    'omnivorous',
    'omomyid',
    'omophagia',
    'omotic',
    'omphalocele',
    'omphalos',
    'omphaloskepsis',
    'omphalotus',
    'omphalus',
    'omsk',
    'on',
    'onager',
    'onagraceae',
    'onanism',
    'onanist',
    'once',
    'onchocerciasis',
    'oncidium',
    'oncogene',
    'oncologic',
    'oncological',
    'oncologist',
    'oncology',
    'oncoming',
    'oncorhynchus',
    'oncovin',
    'ondaatje',
    'ondatra',
    'one',
    'onega',
    'oneida',
    'oneiric',
    'oneirism',
    'oneiromancer',
    'oneiromancy',
    'oneness',
    'onerous',
    'onerously',
    'onerousness',
    'ones',
    'oneself',
    'onetime',
    'ongoing',
    'oni',
    'onion',
    'onions',
    'onionskin',
    'oniscidae',
    'oniscus',
    'online',
    'onlooker',
    'onlookers',
    'only',
    'ono',
    'onobrychis',
    'onoclea',
    'onomancer',
    'onomancy',
    'onomastic',
    'onomasticon',
    'onomastics',
    'onomatomania',
    'onomatopoeia',
    'onomatopoeic',
    'onomatopoeical',
    'onomatopoetic',
    'onondaga',
    'ononis',
    'onopordon',
    'onopordum',
    'onosmodium',
    'onrush',
    'onsager',
    'onset',
    'onshore',
    'onside',
    'onslaught',
    'onstage',
    'ontario',
    'onto',
    'ontogenesis',
    'ontogenetic',
    'ontogeny',
    'ontological',
    'ontology',
    'onus',
    'onward',
    'onychium',
    'onychogalea',
    'onycholysis',
    'onychomys',
    'onychophora',
    'onychophoran',
    'onychophorans',
    'onychosis',
    'onymous',
    'onyx',
    'onyxis',
    'oocyte',
    'oodles',
    'oogenesis',
    'ooh',
    'oohed',
    'oology',
    'oolong',
    'oomph',
    'oomycetes',
    'oophorectomy',
    'oophoritis',
    'oophorosalpingectomy',
    'oort',
    'oosphere',
    'oospore',
    'ootid',
    'oout',
    'ooze',
    'oozed',
    'oozes',
    'oozing',
    'oozy',
    'op',
    'opacification',
    'opacified',
    'opacify',
    'opacity',
    'opah',
    'opahs',
    'opal',
    'opalesce',
    'opalescence',
    'opalescent',
    'opalesces',
    'opaline',
    'opalise',
    'opalize',
    'opaque',
    'opaqueness',
    'opcw',
    'opec',
    'opel',
    'open',
    'openbill',
    'openbills',
    'opencast',
    'opencut',
    'opened',
    'opener',
    'openhanded',
    'openhandedness',
    'openhearted',
    'opening',
    'openings',
    'openly',
    'openmouthed',
    'openness',
    'opens',
    'openwork',
    'opepe',
    'opera',
    'operable',
    'operagoer',
    'operand',
    'operands',
    'operant',
    'operas',
    'operate',
    'operated',
    'operates',
    'operatic',
    'operating',
    'operation',
    'operational',
    'operationalism',
    'operationalist',
    'operations',
    'operative',
    'operatives',
    'operator',
    'operators',
    'operculate',
    'operculated',
    'operculum',
    'operetta',
    'operettas',
    'operon',
    'operose',
    'operoseness',
    'opheodrys',
    'ophidia',
    'ophidian',
    'ophidiidae',
    'ophidism',
    'ophiodon',
    'ophiodontidae',
    'ophioglossaceae',
    'ophioglossales',
    'ophioglossum',
    'ophiolatry',
    'ophiophagus',
    'ophisaurus',
    'ophiuchus',
    'ophiurida',
    'ophiuroidea',
    'ophryon',
    'ophrys',
    'ophthalmectomy',
    'ophthalmia',
    'ophthalmic',
    'ophthalmitis',
    'ophthalmologist',
    'ophthalmologists',
    'ophthalmology',
    'ophthalmoplegia',
    'ophthalmoscope',
    'ophthalmoscopy',
    'opiate',
    'opiates',
    'opiliones',
    'opine',
    'opinion',
    'opinionated',
    'opinionative',
    'opinions',
    'opisthobranchia',
    'opisthocomidae',
    'opisthocomus',
    'opisthognathidae',
    'opisthognathous',
    'opisthorchiasis',
    'opisthotonos',
    'opium',
    'oponent',
    'opopanax',
    'oporto',
    'opossum',
    'opossums',
    'oppenheimer',
    'opponent',
    'opponents',
    'opportune',
    'opportuneness',
    'opportunism',
    'opportunist',
    'opportunistic',
    'opportunities',
    'opportunity',
    'opposable',
    'oppose',
    'opposed',
    'opposer',
    'opposes',
    'opposing',
    'opposite',
    'oppositely',
    'oppositeness',
    'opposites',
    'opposition',
    'oppositive',
    'oppress',
    'oppressed',
    'oppresses',
    'oppression',
    'oppressive',
    'oppressively',
    'oppressiveness',
    'oppressor',
    'opprobrious',
    'opprobrium',
    'oppugn',
    'ops',
    'opsin',
    'opsonin',
    'opsonins',
    'opsonisation',
    'opsonization',
    'opsonize',
    'opt',
    'optative',
    'opted',
    'optez',
    'optic',
    'optical',
    'optically',
    'optician',
    'optics',
    'optimal',
    'optimally',
    'optimisation',
    'optimise',
    'optimism',
    'optimist',
    'optimistic',
    'optimistically',
    'optimization',
    'optimize',
    'optimum',
    'option',
    'optional',
    'options',
    'optometrist',
    'optometry',
    'opulence',
    'opulent',
    'opuntia',
    'opuntiales',
    'opus',
    'opv',
    'or',
    'orach',
    'orache',
    'oracle',
    'oracles',
    'oracular',
    'oradexon',
    'oral',
    'orally',
    'oran',
    'orang',
    'orange',
    'orangeade',
    'orangeman',
    'orangeness',
    'orangery',
    'oranges',
    'orangewood',
    'orangish',
    'orangutan',
    'orangutang',
    'orangutans',
    'orasone',
    'orate',
    'oration',
    'orator',
    'oratorical',
    'oratorio',
    'oratory',
    'orb',
    'orbicular',
    'orbiculate',
    'orbignya',
    'orbison',
    'orbit',
    'orbital',
    'orbitale',
    'orbited',
    'orbiter',
    'orbiting',
    'orbits',
    'orbitual',
    'orca',
    'orchard',
    'orchestia',
    'orchestiidae',
    'orchestra',
    'orchestral',
    'orchestras',
    'orchestrate',
    'orchestrated',
    'orchestrates',
    'orchestration',
    'orchestrator',
    'orchid',
    'orchidaceae',
    'orchidales',
    'orchidalgia',
    'orchidectomy',
    'orchids',
    'orchiectomy',
    'orchil',
    'orchiopexy',
    'orchis',
    'orchitis',
    'orchotomy',
    'orcinus',
    'orcus',
    'orczy',
    'ordain',
    'ordained',
    'ordainer',
    'ordaining',
    'ordeal',
    'order',
    'ordered',
    'orderer',
    'ordering',
    'orderings',
    'orderliness',
    'orderly',
    'orders',
    'ordinal',
    'ordinance',
    'ordinances',
    'ordinand',
    'ordinarily',
    'ordinariness',
    'ordinary',
    'ordinate',
    'ordination',
    'ordnance',
    'ordovician',
    'ordure',
    'ore',
    'oread',
    'oreamnos',
    'orectolobidae',
    'orectolobus',
    'oregano',
    'oregon',
    'oregonian',
    'oreide',
    'oreo',
    'oreopteris',
    'oreortyx',
    'ores',
    'orestes',
    'orff',
    'orford',
    'organ',
    'organdie',
    'organdy',
    'organelle',
    'organelles',
    'organic',
    'organicism',
    'organicistic',
    'organification',
    'organisation',
    'organisational',
    'organise',
    'organised',
    'organiser',
    'organism',
    'organismal',
    'organismic',
    'organisms',
    'organist',
    'organists',
    'organization',
    'organizational',
    'organizations',
    'organize',
    'organized',
    'organizer',
    'organizers',
    'organizes',
    'organizing',
    'organon',
    'organophosphate',
    'organs',
    'organza',
    'orgasm',
    'orgiastic',
    'orgies',
    'orgy',
    'oriel',
    'orient',
    'oriental',
    'orientalise',
    'orientalism',
    'orientalist',
    'orientalize',
    'orientate',
    'orientated',
    'orientating',
    'orientation',
    'oriented',
    'orienting',
    'orients',
    'orifice',
    'oriflamme',
    'origami',
    'origanum',
    'origen',
    'origin',
    'original',
    'originalism',
    'originality',
    'originally',
    'originate',
    'originated',
    'originates',
    'originating',
    'origination',
    'originative',
    'originator',
    'origins',
    'orinasal',
    'orinase',
    'orinoco',
    'oriole',
    'orioles',
    'oriolidae',
    'oriolus',
    'orion',
    'orison',
    'orissa',
    'orites',
    'oriya',
    'orizaba',
    'orlando',
    'orleanais',
    'orleanism',
    'orleanist',
    'orleanists',
    'orleans',
    'orlon',
    'orlop',
    'orly',
    'ormandy',
    'ormazd',
    'ormer',
    'ormolu',
    'ormosia',
    'ormuzd',
    'ornament',
    'ornamental',
    'ornamentalism',
    'ornamentalist',
    'ornamentally',
    'ornamentals',
    'ornamentation',
    'ornamented',
    'ornaments',
    'ornate',
    'ornately',
    'ornateness',
    'orneriness',
    'ornery',
    'ornithine',
    'ornithischia',
    'ornithischian',
    'ornithogalum',
    'ornithological',
    'ornithologist',
    'ornithology',
    'ornithomimid',
    'ornithomimida',
    'ornithopod',
    'ornithopoda',
    'ornithopter',
    'ornithorhynchidae',
    'ornithorhynchus',
    'ornithosis',
    'orobanchaceae',
    'orogeny',
    'orography',
    'oroide',
    'orology',
    'orono',
    'orontium',
    'oropharyngeal',
    'oropharynx',
    'orotund',
    'orozco',
    'orphan',
    'orphanage',
    'orphaned',
    'orphanhood',
    'orphans',
    'orphenadrine',
    'orpheus',
    'orphic',
    'orphrey',
    'orpiment',
    'orpin',
    'orpine',
    'orpington',
    'orr',
    'orrery',
    'orris',
    'orrisroot',
    'ortalis',
    'ortega',
    'orthicon',
    'orthilia',
    'orthochorea',
    'orthoclase',
    'orthodontia',
    'orthodontic',
    'orthodontics',
    'orthodontist',
    'orthodonture',
    'orthodox',
    'orthodoxy',
    'orthoepist',
    'orthoepy',
    'orthogonal',
    'orthogonality',
    'orthographic',
    'orthography',
    'orthomolecular',
    'orthomyxovirus',
    'orthopaedic',
    'orthopaedics',
    'orthopaedist',
    'orthopedic',
    'orthopedical',
    'orthopedics',
    'orthopedist',
    'orthophosphate',
    'orthophosphoric',
    'orthopnea',
    'orthopristis',
    'orthopter',
    'orthoptera',
    'orthopteran',
    'orthopteron',
    'orthoptic',
    'orthoptics',
    'orthoptist',
    'orthoscope',
    'orthostatic',
    'orthotomus',
    'orthotropous',
    'ortolan',
    'ortygan',
    'orudis',
    'orumiyeh',
    'oruvail',
    'orville',
    'orwell',
    'orwellian',
    'orycteropodidae',
    'orycteropus',
    'oryctolagus',
    'oryx',
    'oryxes',
    'oryza',
    'oryzomys',
    'oryzopsis',
    'orzo',
    'os',
    'osage',
    'osaka',
    'osama',
    'osasco',
    'osbert',
    'osborne',
    'oscan',
    'oscar',
    'oscheocele',
    'oscheocoele',
    'oscillate',
    'oscillates',
    'oscillating',
    'oscillation',
    'oscillations',
    'oscillator',
    'oscillatoriaceae',
    'oscillators',
    'oscillatory',
    'oscillogram',
    'oscillograph',
    'oscilloscope',
    'oscine',
    'oscines',
    'oscitance',
    'oscitancy',
    'oscitant',
    'osculate',
    'osculates',
    'osculation',
    'osculator',
    'osha',
    'osier',
    'osiris',
    'oslo',
    'osman',
    'osmanli',
    'osmanthus',
    'osmeridae',
    'osmerus',
    'osmiridium',
    'osmitrol',
    'osmium',
    'osmoreceptor',
    'osmosis',
    'osmotic',
    'osmotically',
    'osmund',
    'osmundaceae',
    'osprey',
    'ospreys',
    'osseous',
    'ossete',
    'ossicle',
    'ossicles',
    'ossicular',
    'ossiculate',
    'ossiculum',
    'ossiferous',
    'ossification',
    'ossified',
    'ossifies',
    'ossify',
    'ossuary',
    'ostariophysi',
    'osteal',
    'osteichthyes',
    'osteitis',
    'ostensible',
    'ostensibly',
    'ostensive',
    'ostensorium',
    'ostentate',
    'ostentation',
    'ostentatious',
    'ostentatiously',
    'ostentatiousness',
    'osteoarthritis',
    'osteoblast',
    'osteoblastoma',
    'osteochondroma',
    'osteoclasis',
    'osteoclast',
    'osteocyte',
    'osteodystrophy',
    'osteoglossidae',
    'osteoglossiformes',
    'osteologer',
    'osteologist',
    'osteology',
    'osteolysis',
    'osteoma',
    'osteomalacia',
    'osteomyelitis',
    'osteopath',
    'osteopathist',
    'osteopathy',
    'osteopetrosis',
    'osteophyte',
    'osteoporosis',
    'osteosarcoma',
    'osteosclerosis',
    'osteostracan',
    'osteostraci',
    'osteotomy',
    'ostiarius',
    'ostiary',
    'ostinato',
    'ostiole',
    'ostler',
    'ostomy',
    'ostraciidae',
    'ostracise',
    'ostracism',
    'ostracize',
    'ostracized',
    'ostracod',
    'ostracoda',
    'ostracoderm',
    'ostracodermi',
    'ostracods',
    'ostrava',
    'ostrea',
    'ostreidae',
    'ostrich',
    'ostriches',
    'ostrogoth',
    'ostrya',
    'ostryopsis',
    'ostwald',
    'ostyak',
    'oswald',
    'otaheite',
    'otalgia',
    'otaria',
    'otariidae',
    'otc',
    'othello',
    'other',
    'otherness',
    'others',
    'otherwise',
    'otherworld',
    'otherworldliness',
    'otherworldly',
    'otho',
    'othonna',
    'otic',
    'otides',
    'otididae',
    'otiose',
    'otis',
    'otitis',
    'oto',
    'otoe',
    'otoganglion',
    'otolaryngologist',
    'otolaryngology',
    'otologist',
    'otology',
    'otoplasty',
    'otorhinolaryngologist',
    'otorhinolaryngology',
    'otorrhea',
    'otosclerosis',
    'otoscope',
    'ototoxic',
    'ottar',
    'ottawa',
    'otter',
    'otterhound',
    'otters',
    'otto',
    'ottoman',
    'ottumwa',
    'otus',
    'ouachita',
    'oubliette',
    'ought',
    'ouguiya',
    'ouija',
    'oujda',
    'ounce',
    'ounces',
    'our',
    'ouranopithecus',
    'ouranos',
    'ours',
    'ourselves',
    'ouse',
    'ousel',
    'oust',
    'ousted',
    'ouster',
    'ousting',
    'ousts',
    'out',
    'outage',
    'outaouais',
    'outback',
    'outbalance',
    'outbid',
    'outboard',
    'outbound',
    'outbrave',
    'outbraved',
    'outbreak',
    'outbreaks',
    'outbred',
    'outbuilding',
    'outburst',
    'outbursts',
    'outcall',
    'outcast',
    'outcaste',
    'outcasts',
    'outclass',
    'outclassed',
    'outcome',
    'outcomes',
    'outcrop',
    'outcropping',
    'outcroppings',
    'outcry',
    'outdated',
    'outdistance',
    'outdistanced',
    'outdo',
    'outdoes',
    'outdoing',
    'outdoor',
    'outdoors',
    'outdoorsman',
    'outdoorswoman',
    'outdoorsy',
    'outdraw',
    'outed',
    'outer',
    'outercourse',
    'outermost',
    'outerwear',
    'outface',
    'outfall',
    'outfield',
    'outfielder',
    'outfight',
    'outfit',
    'outfitted',
    'outfitter',
    'outfitting',
    'outflank',
    'outflow',
    'outflowing',
    'outfought',
    'outfox',
    'outfoxed',
    'outgeneral',
    'outgo',
    'outgoer',
    'outgoing',
    'outgrew',
    'outgrow',
    'outgrown',
    'outgrowth',
    'outgrowths',
    'outguess',
    'outhouse',
    'outing',
    'outlander',
    'outlandish',
    'outlandishness',
    'outlast',
    'outlaw',
    'outlawed',
    'outlawing',
    'outlawry',
    'outlaws',
    'outlay',
    'outlays',
    'outlet',
    'outlets',
    'outlier',
    'outline',
    'outlined',
    'outlines',
    'outlining',
    'outlive',
    'outlived',
    'outlives',
    'outlook',
    'outlying',
    'outmaneuver',
    'outmaneuvered',
    'outmanoeuvre',
    'outmarch',
    'outmatch',
    'outmode',
    'outmoded',
    'outmost',
    'outnumber',
    'outpace',
    'outpatient',
    'outperform',
    'outperforms',
    'outplay',
    'outplayed',
    'outpoint',
    'outport',
    'outpost',
    'outpouring',
    'output',
    'outputting',
    'outrage',
    'outraged',
    'outrageous',
    'outrageously',
    'outrageousness',
    'outran',
    'outrange',
    'outrank',
    'outre',
    'outreach',
    'outride',
    'outrider',
    'outrigged',
    'outrigger',
    'outriggers',
    'outright',
    'outrival',
    'outroar',
    'outrode',
    'outrun',
    'outs',
    'outsail',
    'outsailed',
    'outscore',
    'outsell',
    'outsells',
    'outset',
    'outshine',
    'outshines',
    'outshone',
    'outshout',
    'outside',
    'outsider',
    'outsiders',
    'outsize',
    'outsized',
    'outskirt',
    'outskirts',
    'outsmart',
    'outsole',
    'outsource',
    'outspan',
    'outspoken',
    'outspokenness',
    'outspread',
    'outstanding',
    'outstandingly',
    'outstare',
    'outstation',
    'outstay',
    'outstayed',
    'outstretched',
    'outstrip',
    'outstroke',
    'outtake',
    'outthrust',
    'outturn',
    'outvie',
    'outvote',
    'outvoted',
    'outward',
    'outwardly',
    'outwardness',
    'outwards',
    'outwear',
    'outwears',
    'outweigh',
    'outweighed',
    'outwit',
    'outwork',
    'outworks',
    'ouzel',
    'ouzels',
    'ouzo',
    'ov',
    'ova',
    'oval',
    'ovalbumin',
    'ovalifolium',
    'ovalipes',
    'ovarian',
    'ovariectomy',
    'ovaries',
    'ovaritis',
    'ovary',
    'ovate',
    'ovation',
    'oven',
    'ovenbake',
    'ovenbird',
    'ovenbirds',
    'ovens',
    'ovenware',
    'over',
    'overabundance',
    'overabundant',
    'overachieve',
    'overachievement',
    'overachiever',
    'overact',
    'overacted',
    'overacting',
    'overactive',
    'overactivity',
    'overacts',
    'overage',
    'overaged',
    'overall',
    'overambitious',
    'overanxiety',
    'overanxious',
    'overappraisal',
    'overarch',
    'overarches',
    'overarching',
    'overarm',
    'overawe',
    'overawed',
    'overbalance',
    'overbear',
    'overbearing',
    'overbearingness',
    'overbid',
    'overbite',
    'overblown',
    'overboard',
    'overboil',
    'overbold',
    'overburden',
    'overburdened',
    'overbusy',
    'overcall',
    'overcame',
    'overcapitalisation',
    'overcapitalise',
    'overcapitalization',
    'overcapitalize',
    'overcareful',
    'overcast',
    'overcasting',
    'overcasts',
    'overcautious',
    'overcharge',
    'overclothe',
    'overclothes',
    'overcloud',
    'overcoat',
    'overcoating',
    'overcoats',
    'overcome',
    'overcomer',
    'overcomes',
    'overcoming',
    'overcompensate',
    'overcompensation',
    'overconfidence',
    'overconfident',
    'overcook',
    'overcredulity',
    'overcredulous',
    'overcritical',
    'overcrop',
    'overcropped',
    'overcrossing',
    'overcrowd',
    'overcrowded',
    'overcrowding',
    'overcultivate',
    'overcurious',
    'overdelicate',
    'overdid',
    'overdo',
    'overdone',
    'overdose',
    'overdosed',
    'overdraft',
    'overdrafts',
    'overdramatise',
    'overdramatize',
    'overdramatizing',
    'overdraw',
    'overdress',
    'overdressed',
    'overdrew',
    'overdrive',
    'overdue',
    'overeager',
    'overeat',
    'overeating',
    'overemotional',
    'overemphasis',
    'overemphasise',
    'overemphasize',
    'overenthusiastic',
    'overestimate',
    'overestimated',
    'overestimating',
    'overestimation',
    'overexcited',
    'overexert',
    'overexertion',
    'overexploit',
    'overexploitation',
    'overexpose',
    'overexposed',
    'overexposure',
    'overextend',
    'overextended',
    'overfamiliar',
    'overfatigue',
    'overfed',
    'overfeed',
    'overfeeding',
    'overfill',
    'overfilled',
    'overflight',
    'overflow',
    'overflowed',
    'overflowing',
    'overfly',
    'overfond',
    'overfull',
    'overgarment',
    'overgeneralise',
    'overgeneralize',
    'overgenerous',
    'overgorge',
    'overgreedy',
    'overgrew',
    'overgrow',
    'overgrown',
    'overgrowth',
    'overhand',
    'overhanded',
    'overhang',
    'overhanging',
    'overhasty',
    'overhaul',
    'overhauling',
    'overhead',
    'overhear',
    'overheard',
    'overheat',
    'overheated',
    'overheating',
    'overindulge',
    'overindulgence',
    'overindulgent',
    'overjealous',
    'overjoy',
    'overjoyed',
    'overkill',
    'overladen',
    'overlaid',
    'overland',
    'overlap',
    'overlapping',
    'overlaps',
    'overlarge',
    'overlay',
    'overlayer',
    'overleap',
    'overlie',
    'overlies',
    'overlip',
    'overload',
    'overloaded',
    'overloading',
    'overlook',
    'overlooked',
    'overlooking',
    'overlooks',
    'overlord',
    'overlordship',
    'overly',
    'overlying',
    'overmantel',
    'overmaster',
    'overmodest',
    'overmuch',
    'overmuchness',
    'overnice',
    'overnight',
    'overnighter',
    'overpass',
    'overpasses',
    'overpay',
    'overpayment',
    'overplay',
    'overplus',
    'overpopulate',
    'overpopulation',
    'overpower',
    'overpowering',
    'overpoweringly',
    'overpowers',
    'overpraise',
    'overpressure',
    'overpressures',
    'overprice',
    'overpriced',
    'overprint',
    'overprinting',
    'overproduce',
    'overproduces',
    'overproduction',
    'overprotect',
    'overprotection',
    'overprotective',
    'overproud',
    'overran',
    'overrate',
    'overrating',
    'overreach',
    'overreaching',
    'overreact',
    'overreaction',
    'overreckoning',
    'overrefine',
    'overrefined',
    'overrefinement',
    'overrefining',
    'override',
    'overrides',
    'overriding',
    'overripe',
    'overrule',
    'overruled',
    'overrun',
    'oversaw',
    'oversea',
    'overseas',
    'oversee',
    'overseeing',
    'overseer',
    'oversees',
    'oversensitive',
    'oversensitiveness',
    'overserious',
    'oversew',
    'oversewn',
    'oversexed',
    'overshadow',
    'overshadowed',
    'overshielding',
    'overshoe',
    'overshoot',
    'overshoots',
    'overshot',
    'oversight',
    'oversimplification',
    'oversimplified',
    'oversimplify',
    'oversize',
    'oversized',
    'overskirt',
    'oversleep',
    'oversolicitous',
    'overspecialise',
    'overspecialize',
    'overspecialized',
    'overspend',
    'overspill',
    'overspread',
    'overstate',
    'overstated',
    'overstatement',
    'overstay',
    'overstep',
    'overstepped',
    'overstepping',
    'overstock',
    'overstrain',
    'overstress',
    'overstretch',
    'overstrung',
    'overstuff',
    'overstuffed',
    'oversubscribed',
    'oversupply',
    'oversuspicious',
    'overt',
    'overtake',
    'overtaken',
    'overtaking',
    'overtax',
    'overthrew',
    'overthrow',
    'overthrowing',
    'overthrown',
    'overtime',
    'overtire',
    'overtolerance',
    'overtone',
    'overtones',
    'overtop',
    'overtrump',
    'overture',
    'overturn',
    'overturned',
    'overuse',
    'overutilisation',
    'overutilization',
    'overvaliant',
    'overvaluation',
    'overvalue',
    'overvalued',
    'overview',
    'overweary',
    'overweening',
    'overweight',
    'overwhelm',
    'overwhelmed',
    'overwhelming',
    'overwhelmingly',
    'overwinter',
    'overwintered',
    'overwork',
    'overworking',
    'overwrite',
    'overwrought',
    'overzealous',
    'ovibos',
    'ovid',
    'oviduct',
    'oviducts',
    'oviedo',
    'oviform',
    'ovimbundu',
    'ovine',
    'oviparous',
    'ovipositor',
    'oviraptorid',
    'oviraptorids',
    'ovis',
    'ovocon',
    'ovoflavin',
    'ovoid',
    'ovolo',
    'ovotestis',
    'ovoviviparous',
    'ovral',
    'ovrette',
    'ovular',
    'ovulate',
    'ovulating',
    'ovulation',
    'ovule',
    'ovulen',
    'ovules',
    'ovum',
    'owe',
    'owed',
    'owen',
    'owens',
    'owensboro',
    'owes',
    'owing',
    'owl',
    'owlclaws',
    'owlet',
    'owlish',
    'owls',
    'owlt',
    'own',
    'owned',
    'owner',
    'ownerless',
    'owners',
    'ownership',
    'owning',
    'owns',
    'ox',
    'oxacillin',
    'oxalacetate',
    'oxalacetic',
    'oxalate',
    'oxalic',
    'oxalidaceae',
    'oxalis',
    'oxaloacetate',
    'oxandra',
    'oxaprozin',
    'oxazepam',
    'oxbow',
    'oxbridge',
    'oxcart',
    'oxen',
    'oxeye',
    'oxford',
    'oxheart',
    'oxidant',
    'oxidase',
    'oxidate',
    'oxidation',
    'oxidative',
    'oxide',
    'oxides',
    'oxidisation',
    'oxidise',
    'oxidised',
    'oxidiser',
    'oxidizable',
    'oxidization',
    'oxidize',
    'oxidized',
    'oxidizer',
    'oxidizes',
    'oxidizing',
    'oxidoreductase',
    'oxidoreduction',
    'oxime',
    'oximeter',
    'oxlip',
    'oxonian',
    'oxtail',
    'oxtant',
    'oxtongue',
    'oxyacetylene',
    'oxyacid',
    'oxyacids',
    'oxybelis',
    'oxybenzene',
    'oxycephaly',
    'oxydendrum',
    'oxygen',
    'oxygenase',
    'oxygenate',
    'oxygenated',
    'oxygenates',
    'oxygenation',
    'oxygenise',
    'oxygenize',
    'oxyhaemoglobin',
    'oxyhemoglobin',
    'oxylebius',
    'oxymoron',
    'oxyopia',
    'oxyphenbutazone',
    'oxyphencyclimine',
    'oxytetracycline',
    'oxytocic',
    'oxytocin',
    'oxytone',
    'oxytropis',
    'oxyura',
    'oxyuranus',
    'oxyuridae',
    'oyabun',
    'oyster',
    'oystercatcher',
    'oystercatchers',
    'oysterfish',
    'oysters',
    'ozaena',
    'ozarks',
    'ozawa',
    'ozena',
    'ozocerite',
    'ozokerite',
    'ozone',
    'ozonide',
    'ozonise',
    'ozonium',
    'ozonize',
    'ozonosphere',
    'ozothamnus']



from .bullet_point_cleaner import BulletPointCleaner
from .delimiters_to_periods import DelimitersToPeriods
from .newlines_to_periods import NewlinesToPeriods
from .numbered_list_normalizer import NumberedListNormalizer
from .post_process_sentences import PostProcessStructure
from .spacy_doc_segmenter import SpacyDocSegmenter



# !/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Generic Facade to interact with Pronouns """
from lingpatlab.baseblock import BaseObject


class PronounFinder(BaseObject):
    """ Generic Facade to interact with Pronouns """

    __all = None
    __alphabet = [(chr(ord('a') + i)) for i in range(26)]

    _d_pronouns = {
        '1': [
            'i',
            'me',
            'my',
            'mine',
            'myself',
            'we',
            'us',
            'our',
            'ourselves'
        ],
        '2': [
            'you'
        ],
        '3': [
            'she',
            'her',
            'he',
            'him',
            'it',
            'they',
            'them'
        ]
    }

    def __init__(self):
        """ Change Log:

        Created:
            3-May-2022
            craigtrim@gmail.com
            *   https://github.com/grafflr/graffl-core/issues/345
        """
        BaseObject.__init__(self, __name__)

    def all(self) -> list:
        """
        Returns:
            list: a sorted list of all pronouns
        """
        if not self.__all:
            s = set()

            [s.add(x) for x in self._d_pronouns['1']]  # 1st-Person Pronouns
            [s.add(x) for x in self._d_pronouns['2']]  # 2nd-Person Pronouns
            [s.add(x) for x in self._d_pronouns['3']]  # 3rd-Person Pronouns

            self.__all = sorted(s)

        return self.__all

    def has_pronoun(self,
                    input_text: str) -> bool:
        """ Check if a Pronoun is contained within the Input Text

        Args:
            input_text (str): any input text of any length

        Returns:
            bool: True if a pronoun exists in the input text
        """

        input_text = [ch for ch in input_text.lower()
                      if ch in self.__alphabet or ch == ' ']

        tokens = ''.join(input_text).split()
        tokens = [x.strip().lower() for x in tokens if x.isalpha()]
        tokens = [x for x in tokens if x in self.all()]

        return len(tokens)




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_f_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.156457'}

wordnet_terms_f = [
    'fa',
    'faa',
    'fab',
    'fabaceae',
    'faberge',
    'fabian',
    'fabiana',
    'fabianism',
    'fable',
    'fabled',
    'fables',
    'fabric',
    'fabricate',
    'fabricated',
    'fabricates',
    'fabricating',
    'fabrication',
    'fabricator',
    'fabrics',
    'fabulist',
    'fabulous',
    'facade',
    'face',
    'faced',
    'faceless',
    'facelift',
    'faceplate',
    'facer',
    'faces',
    'facet',
    'faceted',
    'facetious',
    'facetiously',
    'facetiousness',
    'facets',
    'facia',
    'facial',
    'facials',
    'facie',
    'facile',
    'facilitate',
    'facilitates',
    'facilitating',
    'facilitation',
    'facilitative',
    'facilitator',
    'facilitatory',
    'facilities',
    'facility',
    'facing',
    'facsimile',
    'fact',
    'faction',
    'factions',
    'factious',
    'factitious',
    'facto',
    'factoid',
    'factor',
    'factored',
    'factorial',
    'factorials',
    'factories',
    'factoring',
    'factorisation',
    'factorise',
    'factorization',
    'factorize',
    'factors',
    'factory',
    'factotum',
    'facts',
    'factual',
    'factuality',
    'factually',
    'factualness',
    'facula',
    'facultative',
    'faculties',
    'faculty',
    'fad',
    'faddish',
    'faddist',
    'faddy',
    'fade',
    'faded',
    'fadeout',
    'fades',
    'fading',
    'fado',
    'fads',
    'fae',
    'faecal',
    'faecalith',
    'faeces',
    'faerie',
    'faeroes',
    'faeroese',
    'faery',
    'fafnir',
    'fag',
    'fagaceae',
    'fagales',
    'fagged',
    'faggot',
    'faggoting',
    'fagin',
    'fagopyrum',
    'fagot',
    'fagoting',
    'fagotted',
    'fagus',
    'fahd',
    'fahrenheit',
    'faience',
    'fail',
    'failed',
    'failing',
    'failings',
    'faille',
    'fails',
    'failure',
    'failures',
    'fain',
    'faineance',
    'faineant',
    'fainsod',
    'faint',
    'faintest',
    'fainthearted',
    'faintheartedness',
    'faintly',
    'faintness',
    'fair',
    'fairbanks',
    'fairground',
    'fairies',
    'fairish',
    'fairlead',
    'fairly',
    'fairness',
    'fairs',
    'fairway',
    'fairy',
    'fairyland',
    'fairytale',
    'faisal',
    'faisalabad',
    'fait',
    'faith',
    'faithful',
    'faithfulness',
    'faithless',
    'faithlessness',
    'fake',
    'faked',
    'fakeer',
    'faker',
    'fakery',
    'faking',
    'fakir',
    'falafel',
    'falanga',
    'falange',
    'falangist',
    'falcate',
    'falcatifolium',
    'falchion',
    'falciform',
    'falco',
    'falcon',
    'falconer',
    'falconidae',
    'falconiformes',
    'falconine',
    'falconry',
    'falcons',
    'falderol',
    'falkland',
    'falkner',
    'fall',
    'falla',
    'fallacious',
    'fallaciousness',
    'fallacy',
    'fallal',
    'fallback',
    'fallboard',
    'fallen',
    'faller',
    'fallibility',
    'fallible',
    'falling',
    'falloff',
    'fallopian',
    'fallopio',
    'fallopius',
    'fallot',
    'fallout',
    'fallow',
    'falls',
    'false',
    'falsehood',
    'falsely',
    'falseness',
    'falsetto',
    'falsie',
    'falsifiable',
    'falsification',
    'falsified',
    'falsifier',
    'falsifies',
    'falsify',
    'falsifying',
    'falsity',
    'falstaff',
    'falstaffian',
    'falter',
    'faltered',
    'faltering',
    'fame',
    'famed',
    'familial',
    'familiar',
    'familiarisation',
    'familiarise',
    'familiarised',
    'familiarising',
    'familiarity',
    'familiarization',
    'familiarize',
    'familiarized',
    'familiarizing',
    'familiarly',
    'families',
    'family',
    'famine',
    'famish',
    'famished',
    'famishment',
    'famotidine',
    'famous',
    'famulus',
    'fan',
    'fanaloka',
    'fanatic',
    'fanatical',
    'fanatically',
    'fanaticism',
    'fanatics',
    'fanatism',
    'fancied',
    'fancier',
    'fancies',
    'fanciful',
    'fancify',
    'fancy',
    'fancywork',
    'fandango',
    'fandom',
    'fanfare',
    'fanfares',
    'fang',
    'fanged',
    'fangs',
    'fanion',
    'fanjet',
    'fanlight',
    'fanlike',
    'fanned',
    'fanny',
    'fans',
    'fantabulous',
    'fantail',
    'fantan',
    'fantasia',
    'fantasies',
    'fantasise',
    'fantasist',
    'fantasize',
    'fantasizing',
    'fantasm',
    'fantast',
    'fantastic',
    'fantastical',
    'fantastically',
    'fantasy',
    'fantods',
    'fanweed',
    'fanwort',
    'fao',
    'faq',
    'faqir',
    'faquir',
    'far',
    'farad',
    'faraday',
    'farads',
    'farandole',
    'faraway',
    'farawayness',
    'farc',
    'farce',
    'farcical',
    'fardel',
    'fare',
    'fares',
    'farewell',
    'farfalle',
    'farfetched',
    'fargo',
    'farina',
    'farinaceous',
    'farkleberry',
    'farley',
    'farm',
    'farmed',
    'farmer',
    'farmerette',
    'farmers',
    'farmhand',
    'farmhouse',
    'farming',
    'farmington',
    'farmland',
    'farmplace',
    'farms',
    'farmstead',
    'farmyard',
    'farness',
    'faro',
    'faroe',
    'faroes',
    'faroese',
    'farrago',
    'farragut',
    'farrell',
    'farrier',
    'farrow',
    'farrowing',
    'farseeing',
    'farsi',
    'farsighted',
    'farsightedness',
    'fart',
    'farther',
    'farthermost',
    'farthest',
    'farthing',
    'farthingale',
    'farting',
    'fartlek',
    'fas',
    'fasces',
    'fascia',
    'fascicle',
    'fasciculation',
    'fascicule',
    'fasciculus',
    'fascinate',
    'fascinated',
    'fascinates',
    'fascinating',
    'fascination',
    'fasciola',
    'fascioliasis',
    'fasciolidae',
    'fasciolopsiasis',
    'fasciolopsis',
    'fasciolosis',
    'fascism',
    'fascist',
    'fascista',
    'fascistic',
    'fascists',
    'fashion',
    'fashionable',
    'fashioned',
    'fashioning',
    'fashionmonger',
    'fashions',
    'faso',
    'fast',
    'fastball',
    'fasted',
    'fasten',
    'fastened',
    'fastener',
    'fasteners',
    'fastening',
    'fastenings',
    'fastens',
    'faster',
    'fastest',
    'fastidious',
    'fastidiousness',
    'fastigiate',
    'fasting',
    'fastnacht',
    'fastness',
    'fasts',
    'fat',
    'fatah',
    'fatal',
    'fatalism',
    'fatalist',
    'fatalistic',
    'fatalities',
    'fatality',
    'fatally',
    'fatback',
    'fate',
    'fated',
    'fateful',
    'fates',
    'fathead',
    'fatheaded',
    'father',
    'fathered',
    'fatherhood',
    'fathering',
    'fatherland',
    'fatherless',
    'fatherlike',
    'fatherliness',
    'fatherly',
    'fathers',
    'fathom',
    'fathomable',
    'fathometer',
    'fathoms',
    'fatigability',
    'fatigue',
    'fatigued',
    'fatigues',
    'fatiha',
    'fatihah',
    'fatima',
    'fatimah',
    'fatism',
    'fatless',
    'fatness',
    'fats',
    'fatso',
    'fatten',
    'fattened',
    'fattening',
    'fattiness',
    'fattish',
    'fattism',
    'fatty',
    'fatuity',
    'fatuous',
    'fatuousness',
    'fatwa',
    'fatwah',
    'fatwahs',
    'faubourg',
    'faucal',
    'fauces',
    'faucet',
    'fauld',
    'faulkner',
    'fault',
    'faultfinder',
    'faultfinding',
    'faultiness',
    'faulting',
    'faultless',
    'faultlessness',
    'faults',
    'faulty',
    'faun',
    'fauna',
    'fauns',
    'fauntleroy',
    'faunus',
    'faust',
    'faustian',
    'faustus',
    'faut',
    'fauteuil',
    'fauve',
    'fauvism',
    'fauvist',
    'fauvists',
    'faux',
    'fava',
    'faveolate',
    'favism',
    'favor',
    'favorable',
    'favorableness',
    'favorably',
    'favored',
    'favoring',
    'favorite',
    'favoritism',
    'favors',
    'favour',
    'favourable',
    'favourableness',
    'favourite',
    'favouritism',
    'favus',
    'fawkes',
    'fawn',
    'fawner',
    'fawning',
    'fax',
    'faxed',
    'fay',
    'fayetteville',
    'faze',
    'fazed',
    'fbi',
    'fcc',
    'fcs',
    'fda',
    'fdic',
    'fdr',
    'fe',
    'fealty',
    'fear',
    'feared',
    'fearful',
    'fearfulness',
    'fearless',
    'fearlessness',
    'fears',
    'fearsome',
    'feasibility',
    'feasible',
    'feasibleness',
    'feast',
    'feasted',
    'feasting',
    'feasts',
    'feat',
    'feather',
    'featherbed',
    'featherbedding',
    'featherbrained',
    'feathered',
    'featheredge',
    'featheredged',
    'featherfoil',
    'featheriness',
    'feathering',
    'featherless',
    'featherlike',
    'feathers',
    'feathertop',
    'featherweight',
    'feathery',
    'feats',
    'feature',
    'featured',
    'featureless',
    'features',
    'featuring',
    'feb',
    'febricity',
    'febrifuge',
    'febrile',
    'febrility',
    'february',
    'fecal',
    'fecalith',
    'feces',
    'fechner',
    'feckless',
    'fecklessness',
    'fecula',
    'feculence',
    'feculent',
    'fecund',
    'fecundate',
    'fecundation',
    'fecundity',
    'fed',
    'fedayeen',
    'fedelline',
    'federal',
    'federalisation',
    'federalise',
    'federalism',
    'federalist',
    'federalization',
    'federalize',
    'federally',
    'federate',
    'federated',
    'federation',
    'federita',
    'fedora',
    'fee',
    'feeble',
    'feebleminded',
    'feeblemindedness',
    'feebleness',
    'feed',
    'feedback',
    'feedbag',
    'feeder',
    'feeders',
    'feeding',
    'feedlot',
    'feeds',
    'feedstock',
    'feel',
    'feeler',
    'feeling',
    'feelings',
    'feels',
    'fees',
    'feet',
    'feifer',
    'feign',
    'feigned',
    'feigning',
    'feijoa',
    'fein',
    'feint',
    'feinted',
    'feinting',
    'feints',
    'feist',
    'feisty',
    'felafel',
    'feldene',
    'feldspar',
    'feldspars',
    'felicia',
    'felicitate',
    'felicitation',
    'felicitous',
    'felicitousness',
    'felicity',
    'felid',
    'felidae',
    'feline',
    'felis',
    'fell',
    'fella',
    'fellah',
    'fellata',
    'fellate',
    'fellatio',
    'fellation',
    'felled',
    'feller',
    'felling',
    'fellini',
    'felloe',
    'fellow',
    'fellows',
    'fellowship',
    'fellowships',
    'fells',
    'felly',
    'felon',
    'felonious',
    'felony',
    'felspar',
    'felt',
    'felted',
    'felting',
    'felucca',
    'felwort',
    'fema',
    'female',
    'femaleness',
    'females',
    'feminine',
    'feminineness',
    'femininity',
    'feminisation',
    'feminise',
    'feminism',
    'feminist',
    'feminization',
    'feminize',
    'feminizes',
    'femoral',
    'femoris',
    'femtochemistry',
    'femtometer',
    'femtometre',
    'femtosecond',
    'femtovolt',
    'femur',
    'fen',
    'fence',
    'fenced',
    'fencelike',
    'fencer',
    'fences',
    'fencesitter',
    'fencing',
    'fend',
    'fender',
    'fenders',
    'fenestella',
    'fenestra',
    'fenestral',
    'fenestration',
    'fengtien',
    'fenimore',
    'fenland',
    'fennel',
    'fennic',
    'fenoprofen',
    'fenrir',
    'fens',
    'fentanyl',
    'fenugreek',
    'fenusa',
    'feodor',
    'feoff',
    'feosol',
    'feral',
    'ferber',
    'ferdinand',
    'fergon',
    'fergusonite',
    'feria',
    'ferial',
    'ferine',
    'fermat',
    'fermata',
    'ferment',
    'fermentable',
    'fermentation',
    'fermentations',
    'fermented',
    'fermenting',
    'fermentologist',
    'ferments',
    'fermi',
    'fermion',
    'fermium',
    'fern',
    'fernando',
    'ferned',
    'fernless',
    'fernlike',
    'ferns',
    'ferny',
    'ferocactus',
    'ferocious',
    'ferociously',
    'ferociousness',
    'ferocity',
    'ferrara',
    'ferret',
    'ferreted',
    'ferrets',
    'ferric',
    'ferricyanic',
    'ferricyanide',
    'ferries',
    'ferrimagnetism',
    'ferrite',
    'ferrites',
    'ferritin',
    'ferrocerium',
    'ferroconcrete',
    'ferrocyanic',
    'ferrocyanide',
    'ferromagnetic',
    'ferromagnetism',
    'ferrous',
    'ferrule',
    'ferry',
    'ferryboat',
    'ferrying',
    'ferryman',
    'fertile',
    'fertilisation',
    'fertilise',
    'fertilised',
    'fertiliser',
    'fertility',
    'fertilizable',
    'fertilization',
    'fertilize',
    'fertilized',
    'fertilizer',
    'fertilizers',
    'fertilizing',
    'ferule',
    'fervency',
    'fervent',
    'fervid',
    'fervidness',
    'fervor',
    'fervour',
    'fes',
    'fescue',
    'fess',
    'fesse',
    'festal',
    'fester',
    'festering',
    'festinate',
    'festination',
    'festival',
    'festivals',
    'festive',
    'festivities',
    'festivity',
    'festoon',
    'festooned',
    'festoonery',
    'festoons',
    'festschrift',
    'festuca',
    'fet',
    'fetal',
    'fetch',
    'fetched',
    'fetching',
    'fete',
    'feterita',
    'fetich',
    'fetichism',
    'feticide',
    'fetid',
    'fetidness',
    'feting',
    'fetish',
    'fetishes',
    'fetishism',
    'fetishist',
    'fetishize',
    'fetlock',
    'fetology',
    'fetometry',
    'fetoprotein',
    'fetor',
    'fetoscope',
    'fetoscopy',
    'fetter',
    'fetterbush',
    'fettered',
    'fetters',
    'fettle',
    'fettuccine',
    'fettuccini',
    'fetus',
    'fetuses',
    'feud',
    'feudal',
    'feudalism',
    'feudalistic',
    'feudalize',
    'feudatory',
    'feuding',
    'fever',
    'fevered',
    'feverfew',
    'feverish',
    'feverishness',
    'feverous',
    'feverroot',
    'few',
    'fewer',
    'fewest',
    'fewness',
    'fey',
    'feynman',
    'fez',
    'fha',
    'fhlmc',
    'fiance',
    'fiancee',
    'fiasco',
    'fiat',
    'fib',
    'fibber',
    'fibbing',
    'fiber',
    'fiberboard',
    'fiberglass',
    'fiberoptic',
    'fiberoptics',
    'fibers',
    'fiberscope',
    'fibonacci',
    'fibre',
    'fibreboard',
    'fibreglass',
    'fibreoptic',
    'fibreoptics',
    'fibres',
    'fibril',
    'fibrillate',
    'fibrillated',
    'fibrillation',
    'fibrillose',
    'fibrils',
    'fibrin',
    'fibrinase',
    'fibrinogen',
    'fibrinolysin',
    'fibrinolysis',
    'fibrinopeptide',
    'fibrinous',
    'fibroadenoma',
    'fibroblast',
    'fibroblasts',
    'fibrocalcific',
    'fibrocartilage',
    'fibrocartilaginous',
    'fibroid',
    'fibroma',
    'fibromyositis',
    'fibrosis',
    'fibrositis',
    'fibrosity',
    'fibrous',
    'fibrousness',
    'fibula',
    'fica',
    'fice',
    'fichu',
    'fickle',
    'fickleness',
    'fictile',
    'fiction',
    'fictional',
    'fictionalisation',
    'fictionalise',
    'fictionalization',
    'fictionalize',
    'fictionalized',
    'fictitious',
    'fictive',
    'ficus',
    'fiddle',
    'fiddled',
    'fiddlehead',
    'fiddleneck',
    'fiddlenecks',
    'fiddler',
    'fiddles',
    'fiddlestick',
    'fiddling',
    'fide',
    'fidel',
    'fidelity',
    'fidget',
    'fidgetiness',
    'fidgeting',
    'fidgety',
    'fiducial',
    'fiduciary',
    'fiedler',
    'fief',
    'fiefdom',
    'field',
    'fielded',
    'fielder',
    'fielders',
    'fieldfare',
    'fieldhand',
    'fielding',
    'fieldmouse',
    'fields',
    'fieldsman',
    'fieldstone',
    'fieldwork',
    'fieldworker',
    'fiend',
    'fiendish',
    'fierce',
    'fiercely',
    'fierceness',
    'fiercest',
    'fieriness',
    'fiery',
    'fiesta',
    'fife',
    'fifo',
    'fifteen',
    'fifteenth',
    'fifth',
    'fifties',
    'fiftieth',
    'fifty',
    'fig',
    'figeater',
    'fight',
    'fighter',
    'fighters',
    'fighting',
    'fights',
    'figment',
    'figs',
    'figural',
    'figuration',
    'figurative',
    'figuratively',
    'figure',
    'figured',
    'figurehead',
    'figurer',
    'figures',
    'figurine',
    'figuring',
    'figwort',
    'figworts',
    'fiji',
    'fijian',
    'fijis',
    'filaggrin',
    'filago',
    'filagree',
    'filament',
    'filamentlike',
    'filamentous',
    'filaments',
    'filar',
    'filaree',
    'filaria',
    'filarial',
    'filariasis',
    'filariid',
    'filariidae',
    'filature',
    'filbert',
    'filberts',
    'filch',
    'file',
    'filed',
    'filefish',
    'filefishes',
    'filename',
    'filer',
    'files',
    'filet',
    'filial',
    'filiate',
    'filiated',
    'filiation',
    'filibuster',
    'filibusterer',
    'filicales',
    'filicide',
    'filicinae',
    'filicopsida',
    'filiform',
    'filigree',
    'filing',
    'filipino',
    'filippo',
    'fill',
    'fillagree',
    'fille',
    'filled',
    'filler',
    'fillers',
    'fillet',
    'fillets',
    'filling',
    'fillings',
    'fillip',
    'fillmore',
    'fills',
    'filly',
    'film',
    'filmable',
    'filmdom',
    'filmed',
    'filming',
    'filmmaker',
    'films',
    'filmy',
    'filoviridae',
    'filovirus',
    'fils',
    'filter',
    'filtered',
    'filtering',
    'filters',
    'filth',
    'filthiness',
    'filthy',
    'filtrate',
    'filtration',
    'filum',
    'fimbria',
    'fimbriate',
    'fin',
    'finable',
    'finagle',
    'finagler',
    'final',
    'finale',
    'finalisation',
    'finalise',
    'finalist',
    'finalists',
    'finality',
    'finalization',
    'finalize',
    'finalizing',
    'finally',
    'finance',
    'financed',
    'finances',
    'financial',
    'financially',
    'financier',
    'financing',
    'finback',
    'fincen',
    'finch',
    'finches',
    'find',
    'finder',
    'finding',
    'findings',
    'finds',
    'fine',
    'fineable',
    'fined',
    'finedraw',
    'finely',
    'fineness',
    'finer',
    'finery',
    'fines',
    'finespun',
    'finesse',
    'finest',
    'finger',
    'fingerboard',
    'fingerbreadth',
    'fingered',
    'fingerflower',
    'fingering',
    'fingerless',
    'fingerlike',
    'fingerling',
    'fingermark',
    'fingernail',
    'fingernails',
    'fingerpaint',
    'fingerpointing',
    'fingerpost',
    'fingerprint',
    'fingerprinting',
    'fingerprints',
    'fingerroot',
    'fingers',
    'fingerspell',
    'fingerspelling',
    'fingerstall',
    'fingertip',
    'fingertips',
    'finial',
    'finical',
    'finicky',
    'finis',
    'finish',
    'finished',
    'finisher',
    'finishers',
    'finishes',
    'finishing',
    'finite',
    'finiteness',
    'finitude',
    'fink',
    'finland',
    'finn',
    'finnan',
    'finnbogadottir',
    'finned',
    'finnic',
    'finning',
    'finnish',
    'finocchio',
    'fins',
    'fiord',
    'fipple',
    'fir',
    'fire',
    'firearm',
    'firearms',
    'fireball',
    'firebase',
    'firebird',
    'fireboat',
    'firebomb',
    'firebox',
    'firebrand',
    'firebrat',
    'firebrats',
    'firebreak',
    'firebrick',
    'firebug',
    'firebugs',
    'fireclay',
    'firecracker',
    'firecrackers',
    'fired',
    'firedamp',
    'firedog',
    'firedrake',
    'firefighter',
    'firefighters',
    'fireflies',
    'firefly',
    'fireguard',
    'firehouse',
    'firelight',
    'firelighter',
    'firelock',
    'fireman',
    'firemen',
    'firenze',
    'fireplace',
    'fireplaces',
    'fireplug',
    'firepower',
    'fireproof',
    'fireroom',
    'fires',
    'fireside',
    'firestone',
    'firestorm',
    'firethorn',
    'firetrap',
    'firewall',
    'firewater',
    'fireweed',
    'firewood',
    'firework',
    'fireworks',
    'firing',
    'firkin',
    'firm',
    'firmament',
    'firmamental',
    'firmer',
    'firmiana',
    'firmly',
    'firmness',
    'firms',
    'firmware',
    'firs',
    'first',
    'firstborn',
    'firsthand',
    'firth',
    'fisa',
    'fisc',
    'fiscal',
    'fischer',
    'fish',
    'fishbone',
    'fishbowl',
    'fished',
    'fisher',
    'fisheries',
    'fisherman',
    'fishermen',
    'fishery',
    'fishes',
    'fisheye',
    'fishgig',
    'fishhook',
    'fishing',
    'fishmonger',
    'fishnet',
    'fishnets',
    'fishpaste',
    'fishplate',
    'fishpond',
    'fishtail',
    'fishtailed',
    'fishwife',
    'fishworm',
    'fishy',
    'fissile',
    'fission',
    'fissionable',
    'fissions',
    'fissiparity',
    'fissiparous',
    'fissiped',
    'fissipedia',
    'fissure',
    'fissured',
    'fissurella',
    'fissurellidae',
    'fissures',
    'fist',
    'fistfight',
    'fistful',
    'fisticuffs',
    'fistmele',
    'fists',
    'fistula',
    'fistular',
    'fistularia',
    'fistulariidae',
    'fistulate',
    'fistulina',
    'fistulinaceae',
    'fistulous',
    'fit',
    'fitch',
    'fitful',
    'fitfulness',
    'fitment',
    'fitness',
    'fits',
    'fitted',
    'fitter',
    'fitters',
    'fittest',
    'fitting',
    'fittingly',
    'fittingness',
    'fittings',
    'fitzgerald',
    'five',
    'fivefold',
    'fivepence',
    'fiver',
    'fives',
    'fivesome',
    'fix',
    'fixate',
    'fixated',
    'fixates',
    'fixating',
    'fixation',
    'fixative',
    'fixed',
    'fixedly',
    'fixedness',
    'fixer',
    'fixes',
    'fixing',
    'fixings',
    'fixity',
    'fixture',
    'fixtures',
    'fizgig',
    'fizz',
    'fizzes',
    'fizzing',
    'fizzle',
    'fizzy',
    'fjord',
    'fl',
    'flab',
    'flabbergast',
    'flabbergasted',
    'flabbiness',
    'flabby',
    'flaccid',
    'flaccidity',
    'flack',
    'flacourtia',
    'flacourtiaceae',
    'flag',
    'flagella',
    'flagellant',
    'flagellata',
    'flagellate',
    'flagellated',
    'flagellates',
    'flagellation',
    'flagellum',
    'flageolet',
    'flagfish',
    'flagfishes',
    'flagged',
    'flagging',
    'flagitious',
    'flagon',
    'flagpole',
    'flagrant',
    'flagrantly',
    'flagroot',
    'flags',
    'flagship',
    'flagstaff',
    'flagstone',
    'flagstones',
    'flagyl',
    'flail',
    'flair',
    'flak',
    'flake',
    'flaked',
    'flakes',
    'flakey',
    'flakiness',
    'flaking',
    'flaky',
    'flambe',
    'flambeau',
    'flamboyance',
    'flamboyant',
    'flamboyantly',
    'flame',
    'flamed',
    'flamefish',
    'flameflower',
    'flamen',
    'flamenco',
    'flameproof',
    'flames',
    'flamethrower',
    'flamethrowers',
    'flaming',
    'flamingo',
    'flamingos',
    'flaminian',
    'flaminius',
    'flammability',
    'flammable',
    'flammulina',
    'flan',
    'flanders',
    'flange',
    'flank',
    'flanker',
    'flanking',
    'flanks',
    'flannel',
    'flannelbush',
    'flannelette',
    'flap',
    'flapcake',
    'flapjack',
    'flapped',
    'flapper',
    'flapping',
    'flaps',
    'flare',
    'flared',
    'flares',
    'flaring',
    'flash',
    'flashback',
    'flashbacks',
    'flashboard',
    'flashboarding',
    'flashbulb',
    'flashcard',
    'flashed',
    'flasher',
    'flashes',
    'flashflood',
    'flashgun',
    'flashily',
    'flashiness',
    'flashing',
    'flashings',
    'flashlight',
    'flashlights',
    'flashover',
    'flashpoint',
    'flashy',
    'flask',
    'flaskful',
    'flat',
    'flatbed',
    'flatboat',
    'flatbottom',
    'flatbottomed',
    'flatbread',
    'flatbrod',
    'flatcar',
    'flatfish',
    'flatfishes',
    'flatfoot',
    'flatfooted',
    'flathead',
    'flatheads',
    'flatiron',
    'flatlet',
    'flatly',
    'flatmate',
    'flatness',
    'flats',
    'flatten',
    'flattened',
    'flattening',
    'flattens',
    'flatter',
    'flatterer',
    'flattering',
    'flattery',
    'flattop',
    'flatulence',
    'flatulency',
    'flatulent',
    'flatus',
    'flatware',
    'flatwork',
    'flatworm',
    'flatworms',
    'flaubert',
    'flaunt',
    'flaunted',
    'flaunty',
    'flautist',
    'flavian',
    'flavin',
    'flaviviridae',
    'flavivirus',
    'flavone',
    'flavonoid',
    'flavor',
    'flavored',
    'flavorer',
    'flavorful',
    'flavoring',
    'flavorings',
    'flavorless',
    'flavorlessness',
    'flavorous',
    'flavors',
    'flavorsome',
    'flavorsomeness',
    'flavour',
    'flavourer',
    'flavourful',
    'flavouring',
    'flavourless',
    'flavourlessness',
    'flavourous',
    'flavoursome',
    'flavoursomeness',
    'flaw',
    'flawed',
    'flawless',
    'flawlessness',
    'flaws',
    'flax',
    'flaxedil',
    'flaxen',
    'flaxseed',
    'flay',
    'flea',
    'fleabag',
    'fleabane',
    'fleapit',
    'fleas',
    'fleawort',
    'flecainide',
    'fleck',
    'flecked',
    'flecks',
    'flection',
    'fled',
    'fledge',
    'fledged',
    'fledgeless',
    'fledgeling',
    'fledging',
    'fledgling',
    'flee',
    'fleece',
    'fleeceable',
    'fleeces',
    'fleecy',
    'fleeing',
    'fleer',
    'flees',
    'fleet',
    'fleeting',
    'fleetingness',
    'fleetness',
    'fleets',
    'fleming',
    'flemish',
    'flense',
    'flesh',
    'fleshed',
    'fleshiness',
    'fleshing',
    'fleshly',
    'fleshy',
    'fletc',
    'fletcher',
    'flew',
    'flex',
    'flexed',
    'flexeril',
    'flexes',
    'flexibility',
    'flexible',
    'flexibleness',
    'flexibly',
    'flexile',
    'flexion',
    'flexor',
    'flexuous',
    'flexure',
    'flibbertigibbet',
    'flick',
    'flicked',
    'flicker',
    'flickering',
    'flickertail',
    'flicks',
    'flied',
    'flier',
    'fliers',
    'flies',
    'flight',
    'flighted',
    'flightiness',
    'flightless',
    'flights',
    'flighty',
    'flimflam',
    'flimsiness',
    'flimsy',
    'flinch',
    'flinched',
    'flinders',
    'flindersia',
    'flindosa',
    'flindosy',
    'fling',
    'flinging',
    'flint',
    'flinthead',
    'flintlock',
    'flints',
    'flintstone',
    'flinty',
    'flip',
    'flippancy',
    'flippant',
    'flipped',
    'flipper',
    'flippers',
    'flipping',
    'flirt',
    'flirtation',
    'flirtatious',
    'flirting',
    'flirts',
    'flit',
    'flitch',
    'flitted',
    'flitter',
    'flnc',
    'flo',
    'float',
    'floatation',
    'floated',
    'floater',
    'floating',
    'floatplane',
    'floats',
    'floaty',
    'floc',
    'floccose',
    'flocculate',
    'flocculated',
    'flocculation',
    'floccule',
    'flocculent',
    'flock',
    'flocked',
    'flocks',
    'flodden',
    'floe',
    'floes',
    'flog',
    'flogged',
    'flogger',
    'flogging',
    'flogs',
    'flood',
    'flooded',
    'floodgate',
    'floodgates',
    'floodhead',
    'floodheads',
    'flooding',
    'floodlight',
    'floodlighted',
    'floodlights',
    'floodlit',
    'floodplain',
    'floods',
    'floor',
    'floorboard',
    'floorboards',
    'floored',
    'flooring',
    'floors',
    'floorshow',
    'floorwalker',
    'floozie',
    'floozy',
    'flop',
    'flophouse',
    'flopped',
    'floppy',
    'flops',
    'flora',
    'floral',
    'floreal',
    'florence',
    'florentine',
    'florescence',
    'floret',
    'florets',
    'florey',
    'floricultural',
    'floriculture',
    'florid',
    'florida',
    'floridian',
    'floridity',
    'floridness',
    'florilegium',
    'florin',
    'florio',
    'florist',
    'florists',
    'flory',
    'floss',
    'flossy',
    'flotation',
    'flotilla',
    'flotsam',
    'flounce',
    'flounder',
    'floundering',
    'flounders',
    'flour',
    'flourish',
    'flourished',
    'flourishes',
    'flourishing',
    'floury',
    'flout',
    'flouter',
    'flow',
    'flowage',
    'flowchart',
    'flowed',
    'flower',
    'flowerbed',
    'flowered',
    'floweret',
    'flowering',
    'flowerless',
    'flowerpot',
    'flowers',
    'flowery',
    'flowing',
    'flown',
    'flows',
    'floxuridine',
    'flu',
    'flub',
    'fluctuate',
    'fluctuates',
    'fluctuating',
    'fluctuation',
    'fluctuations',
    'flue',
    'fluegelhorn',
    'fluency',
    'fluent',
    'fluently',
    'flues',
    'fluff',
    'fluffed',
    'fluffiness',
    'fluffy',
    'flugelhorn',
    'fluid',
    'fluidity',
    'fluidness',
    'fluidounce',
    'fluidram',
    'fluids',
    'fluke',
    'flukes',
    'flukey',
    'fluky',
    'flume',
    'flummery',
    'flummox',
    'flump',
    'flung',
    'flunitrazepan',
    'flunk',
    'flunkey',
    'flunks',
    'flunky',
    'fluor',
    'fluorapatite',
    'fluoresce',
    'fluorescein',
    'fluoresceine',
    'fluorescence',
    'fluorescent',
    'fluoridate',
    'fluoridation',
    'fluoride',
    'fluorides',
    'fluoridisation',
    'fluoridise',
    'fluoridization',
    'fluoridize',
    'fluorine',
    'fluorite',
    'fluoroboric',
    'fluoroboride',
    'fluorocarbon',
    'fluorochrome',
    'fluorochromes',
    'fluoroform',
    'fluoroscope',
    'fluoroscopy',
    'fluorosis',
    'fluorouracil',
    'fluorspar',
    'fluosilicate',
    'fluosilicic',
    'fluoxetine',
    'fluphenazine',
    'flurazepam',
    'flurbiprofen',
    'flurry',
    'flush',
    'flushed',
    'flushing',
    'fluster',
    'flustered',
    'flute',
    'fluted',
    'flutes',
    'fluting',
    'flutist',
    'flutter',
    'fluttered',
    'fluttering',
    'fluvastatin',
    'fluvial',
    'flux',
    'fluxion',
    'fluxmeter',
    'fly',
    'flyaway',
    'flyblown',
    'flybridge',
    'flycatcher',
    'flycatchers',
    'flycatching',
    'flyer',
    'flyfish',
    'flying',
    'flyleaf',
    'flyover',
    'flypaper',
    'flypast',
    'flyspeck',
    'flyswat',
    'flyswatter',
    'flytrap',
    'flyway',
    'flyweight',
    'flywheel',
    'fm',
    'fmri',
    'fnma',
    'fo',
    'foal',
    'foam',
    'foamed',
    'foamflower',
    'foaminess',
    'foaming',
    'foamy',
    'fob',
    'focal',
    'focalisation',
    'focalise',
    'focalization',
    'focalize',
    'foci',
    'focus',
    'focused',
    'focuses',
    'focusing',
    'focussed',
    'focussing',
    'fodder',
    'foe',
    'foehn',
    'foeman',
    'foeniculum',
    'foes',
    'foetal',
    'foetid',
    'foetidus',
    'foetology',
    'foetometry',
    'foetoprotein',
    'foetor',
    'foetoscope',
    'foetoscopy',
    'foetus',
    'fog',
    'fogbank',
    'fogbound',
    'fogey',
    'fogged',
    'fogginess',
    'fogging',
    'foggy',
    'foghorn',
    'foglamp',
    'fogsignal',
    'fogy',
    'fogyish',
    'fohn',
    'foible',
    'foibles',
    'foil',
    'foiled',
    'foiling',
    'foils',
    'foist',
    'foisted',
    'folacin',
    'folate',
    'fold',
    'foldable',
    'foldaway',
    'folded',
    'folder',
    'folderal',
    'folderol',
    'folding',
    'foldout',
    'folds',
    'foliaceous',
    'foliage',
    'foliaged',
    'foliate',
    'foliated',
    'foliation',
    'folic',
    'folie',
    'folio',
    'foliolate',
    'foliose',
    'folium',
    'folk',
    'folklore',
    'folks',
    'folksong',
    'folksy',
    'folktale',
    'folktales',
    'follicle',
    'follicles',
    'follicular',
    'folliculitis',
    'follies',
    'follow',
    'followed',
    'follower',
    'followers',
    'following',
    'follows',
    'followup',
    'folly',
    'foment',
    'fomentation',
    'fomenter',
    'foments',
    'fomes',
    'fomite',
    'fomor',
    'fomorian',
    'fond',
    'fonda',
    'fondant',
    'fondle',
    'fondled',
    'fondler',
    'fondlers',
    'fondles',
    'fondling',
    'fondly',
    'fondness',
    'fondu',
    'fondue',
    'font',
    'fontanel',
    'fontanelle',
    'fontanelles',
    'fontanne',
    'fontenoy',
    'fonteyn',
    'food',
    'foodie',
    'foodless',
    'foods',
    'foodstuff',
    'foodstuffs',
    'fool',
    'foolery',
    'foolhardiness',
    'foolhardy',
    'fooling',
    'foolish',
    'foolishly',
    'foolishness',
    'foolproof',
    'fools',
    'foolscap',
    'foot',
    'footage',
    'football',
    'footballer',
    'footballs',
    'footbath',
    'footboard',
    'footbridge',
    'footcandle',
    'footed',
    'footedness',
    'footer',
    'footfall',
    'footfault',
    'footgear',
    'foothill',
    'foothills',
    'foothold',
    'footholds',
    'footing',
    'footle',
    'footless',
    'footlights',
    'footling',
    'footlocker',
    'footloose',
    'footman',
    'footmark',
    'footmen',
    'footnote',
    'footnotes',
    'footpad',
    'footpath',
    'footplate',
    'footprint',
    'footprints',
    'footrace',
    'footrest',
    'footslog',
    'footslogger',
    'footsore',
    'footstall',
    'footstep',
    'footsteps',
    'footstool',
    'footsure',
    'footwall',
    'footwear',
    'footwork',
    'fop',
    'foppish',
    'foppishness',
    'for',
    'forage',
    'forager',
    'forages',
    'foraging',
    'foram',
    'foramen',
    'foramina',
    'foraminifer',
    'foraminifera',
    'foraminifers',
    'foray',
    'forays',
    'forbade',
    'forbear',
    'forbearance',
    'forbearing',
    'forbid',
    'forbiddance',
    'forbidden',
    'forbidding',
    'forbids',
    'forbore',
    'forborne',
    'force',
    'forced',
    'forceful',
    'forcefully',
    'forcefulness',
    'forceless',
    'forcemeat',
    'forceps',
    'forces',
    'forcible',
    'forcibly',
    'forcing',
    'forcipate',
    'ford',
    'fordable',
    'forded',
    'fordhooks',
    'fording',
    'fore',
    'forearm',
    'forearms',
    'forebear',
    'forebears',
    'forebode',
    'foreboding',
    'forebrain',
    'forecast',
    'forecaster',
    'forecasting',
    'forecastle',
    'forecasts',
    'foreclose',
    'foreclosing',
    'foreclosure',
    'forecourt',
    'foredate',
    'foredeck',
    'foredge',
    'foredoom',
    'forefather',
    'forefathers',
    'forefeet',
    'forefend',
    'forefinger',
    'forefoot',
    'forefront',
    'foregather',
    'forego',
    'foregoing',
    'foregone',
    'foreground',
    'foregrounding',
    'forehand',
    'forehanded',
    'forehead',
    'foreign',
    'foreigner',
    'foreigners',
    'foreignness',
    'foreknow',
    'foreknowledge',
    'forelady',
    'foreland',
    'foreleg',
    'forelegs',
    'forelimb',
    'forelimbs',
    'forelock',
    'foreman',
    'foremanship',
    'foremast',
    'foremilk',
    'foremost',
    'foremother',
    'forename',
    'forenoon',
    'forensic',
    'forensics',
    'foreordain',
    'foreordained',
    'foreordination',
    'forepart',
    'forepaw',
    'foreperson',
    'foreplay',
    'forequarter',
    'forerunner',
    'forerunners',
    'foresail',
    'foresaw',
    'foresee',
    'foreseeable',
    'foreseeing',
    'foreshadow',
    'foreshadowed',
    'foreshadowing',
    'foreshadows',
    'foreshank',
    'foreshock',
    'foreshore',
    'foreshorten',
    'foreshortened',
    'foreshow',
    'foresight',
    'foresighted',
    'foresightedness',
    'foresightful',
    'foresightfulness',
    'foreskin',
    'forest',
    'forestage',
    'forestall',
    'forestalling',
    'forestay',
    'forested',
    'forester',
    'forestiera',
    'forestry',
    'forests',
    'foreswear',
    'foreswearing',
    'foretaste',
    'foretell',
    'foretelling',
    'foretells',
    'forethought',
    'forethoughtful',
    'foretoken',
    'foretold',
    'foretop',
    'forever',
    'forewarn',
    'forewarned',
    'forewarning',
    'forewing',
    'forewings',
    'forewoman',
    'foreword',
    'forfeit',
    'forfeited',
    'forfeits',
    'forfeiture',
    'forfend',
    'forficate',
    'forficula',
    'forficulidae',
    'forgather',
    'forgave',
    'forge',
    'forged',
    'forger',
    'forgeries',
    'forgery',
    'forges',
    'forget',
    'forgetful',
    'forgetfulness',
    'forgets',
    'forgettable',
    'forgetting',
    'forging',
    'forgings',
    'forgivable',
    'forgive',
    'forgiven',
    'forgiveness',
    'forgiver',
    'forgives',
    'forgiving',
    'forgivingness',
    'forgo',
    'forgoing',
    'forgot',
    'forgotten',
    'forint',
    'fork',
    'forked',
    'forking',
    'forklift',
    'forks',
    'forlorn',
    'forlornness',
    'form',
    'forma',
    'formal',
    'formaldehyde',
    'formalin',
    'formalisation',
    'formalise',
    'formalised',
    'formalism',
    'formalistic',
    'formalities',
    'formality',
    'formalization',
    'formalize',
    'formalized',
    'formally',
    'formalness',
    'formalwear',
    'format',
    'formation',
    'formations',
    'formative',
    'formats',
    'formatting',
    'formed',
    'former',
    'formerly',
    'formic',
    'formica',
    'formicariidae',
    'formicarius',
    'formicary',
    'formicate',
    'formication',
    'formicidae',
    'formidability',
    'formidable',
    'forming',
    'formless',
    'formol',
    'formosa',
    'formosan',
    'forms',
    'formula',
    'formulaic',
    'formularise',
    'formularize',
    'formulary',
    'formulas',
    'formulate',
    'formulated',
    'formulates',
    'formulating',
    'formulation',
    'formulations',
    'fornax',
    'fornicate',
    'fornication',
    'fornicator',
    'fornicatress',
    'fornix',
    'forrestal',
    'forsake',
    'forsaken',
    'forsaking',
    'forseti',
    'forswear',
    'forswearing',
    'forsythia',
    'fort',
    'fortaz',
    'forte',
    'fortemente',
    'forth',
    'forthcoming',
    'forthcomingness',
    'forthright',
    'forthrightness',
    'forties',
    'fortieth',
    'fortification',
    'fortifications',
    'fortified',
    'fortify',
    'fortissimo',
    'fortitude',
    'fortnight',
    'fortnightly',
    'fortran',
    'fortress',
    'fortresses',
    'fortuitous',
    'fortuitousness',
    'fortuity',
    'fortuna',
    'fortunate',
    'fortunately',
    'fortune',
    'fortunella',
    'fortunes',
    'fortuneteller',
    'fortunetellers',
    'fortunetelling',
    'forty',
    'forum',
    'forward',
    'forwarding',
    'forwardness',
    'forwards',
    'foryml',
    'fosamax',
    'fosbury',
    'fossa',
    'fosse',
    'fossil',
    'fossiliferous',
    'fossilisation',
    'fossilise',
    'fossilised',
    'fossilist',
    'fossilization',
    'fossilize',
    'fossilized',
    'fossilizing',
    'fossilology',
    'fossils',
    'fossorial',
    'foster',
    'fosterage',
    'fostered',
    'fostering',
    'fosterling',
    'fothergilla',
    'fots',
    'foucault',
    'fought',
    'foul',
    'foulard',
    'fouled',
    'foulmart',
    'foulness',
    'foumart',
    'found',
    'foundation',
    'foundations',
    'founded',
    'founder',
    'foundering',
    'founders',
    'founding',
    'foundling',
    'foundlings',
    'foundress',
    'foundry',
    'founds',
    'fount',
    'fountain',
    'fountainhead',
    'fountains',
    'fouquieria',
    'fouquieriaceae',
    'four',
    'fourfold',
    'fourhanded',
    'fourier',
    'fourpence',
    'fourpenny',
    'fours',
    'fourscore',
    'foursome',
    'foursquare',
    'fourteen',
    'fourteenth',
    'fourth',
    'fovea',
    'fowl',
    'fowler',
    'fowling',
    'fox',
    'foxberry',
    'foxes',
    'foxglove',
    'foxhole',
    'foxhound',
    'foxhounds',
    'foxhunt',
    'foxiness',
    'foxtail',
    'foxtails',
    'foxtrot',
    'foxy',
    'foyer',
    'fpd',
    'fps',
    'fr',
    'fra',
    'fracas',
    'fractal',
    'fractals',
    'fraction',
    'fractional',
    'fractionate',
    'fractionation',
    'fractions',
    'fractious',
    'fractiousness',
    'fracture',
    'fractured',
    'fractures',
    'fracturing',
    'fradicin',
    'fragaria',
    'fragile',
    'fragility',
    'fragment',
    'fragmental',
    'fragmentary',
    'fragmentation',
    'fragmented',
    'fragmentise',
    'fragmentize',
    'fragments',
    'fragonard',
    'fragrance',
    'fragrancy',
    'fragrant',
    'frail',
    'frailness',
    'frailty',
    'fraise',
    'frambesia',
    'framboesia',
    'framboise',
    'frame',
    'framed',
    'framer',
    'framers',
    'frames',
    'framework',
    'framing',
    'franc',
    'franca',
    'france',
    'frances',
    'franchise',
    'francis',
    'franciscan',
    'francisco',
    'francisella',
    'francium',
    'franck',
    'franco',
    'francoa',
    'francois',
    'francophil',
    'francophile',
    'francophobe',
    'frangibility',
    'frangible',
    'frangibleness',
    'frangipane',
    'frangipani',
    'frangipanni',
    'frank',
    'frankenstein',
    'frankfort',
    'frankfurt',
    'frankfurter',
    'frankfurters',
    'frankincense',
    'frankish',
    'franklin',
    'frankliniella',
    'frankly',
    'frankness',
    'franks',
    'frantic',
    'franz',
    'frap',
    'frappe',
    'frasera',
    'frat',
    'fratercula',
    'fraternal',
    'fraternisation',
    'fraternise',
    'fraternity',
    'fraternization',
    'fraternize',
    'fratricide',
    'frau',
    'fraud',
    'fraudulence',
    'fraudulent',
    'fraudulently',
    'fraught',
    'fraulein',
    'fraxinella',
    'fraxinus',
    'fray',
    'frayed',
    'frazer',
    'frazzle',
    'frazzled',
    'freak',
    'freaked',
    'freakish',
    'freakishness',
    'freaky',
    'freckle',
    'freckled',
    'freckles',
    'fred',
    'frederick',
    'fredericksburg',
    'fredericton',
    'free',
    'freebee',
    'freebie',
    'freebooter',
    'freeborn',
    'freed',
    'freedman',
    'freedom',
    'freedoms',
    'freedwoman',
    'freehand',
    'freehanded',
    'freehearted',
    'freehold',
    'freeholder',
    'freeholders',
    'freeing',
    'freelance',
    'freelancer',
    'freeload',
    'freeloader',
    'freely',
    'freemail',
    'freeman',
    'freemason',
    'freemasonry',
    'freemasons',
    'freer',
    'frees',
    'freesia',
    'freestanding',
    'freestone',
    'freestyle',
    'freetail',
    'freethinker',
    'freethinking',
    'freetown',
    'freeware',
    'freeway',
    'freeways',
    'freewheel',
    'freewheeler',
    'freewheeling',
    'freewill',
    'freewoman',
    'freeze',
    'freezer',
    'freezes',
    'freezing',
    'fregata',
    'fregatidae',
    'freight',
    'freightage',
    'freighter',
    'fremont',
    'fremontia',
    'fremontodendron',
    'french',
    'frenchify',
    'frenchman',
    'frenchmen',
    'frenchwoman',
    'frenetic',
    'frenzied',
    'frenzy',
    'freon',
    'frequence',
    'frequencies',
    'frequency',
    'frequent',
    'frequentative',
    'frequented',
    'frequenter',
    'frequenting',
    'frequently',
    'frequents',
    'frere',
    'fresco',
    'frescoes',
    'fresh',
    'freshen',
    'freshened',
    'freshener',
    'freshens',
    'fresher',
    'freshet',
    'freshly',
    'freshman',
    'freshmen',
    'freshness',
    'freshwater',
    'fresnel',
    'fresno',
    'fress',
    'fret',
    'fretful',
    'fretfulness',
    'frets',
    'fretsaw',
    'fretted',
    'fretting',
    'fretwork',
    'freud',
    'freudian',
    'frey',
    'freya',
    'freyja',
    'freyr',
    'frg',
    'fri',
    'friability',
    'friable',
    'friar',
    'friars',
    'friary',
    'fricandeau',
    'fricassee',
    'fricative',
    'frick',
    'friction',
    'frictional',
    'frictionless',
    'friday',
    'fridge',
    'fried',
    'friedan',
    'friedcake',
    'friedman',
    'friedrich',
    'friend',
    'friendless',
    'friendlessness',
    'friendlier',
    'friendliness',
    'friendly',
    'friends',
    'friendship',
    'frier',
    'fries',
    'friesian',
    'friesland',
    'frieze',
    'frigate',
    'frigates',
    'frigg',
    'frigga',
    'fright',
    'frighten',
    'frightened',
    'frightening',
    'frightens',
    'frightful',
    'frightfulness',
    'frigid',
    'frigidity',
    'frigidness',
    'frigorific',
    'frijol',
    'frijole',
    'frijolillo',
    'frijolito',
    'frill',
    'frilled',
    'frills',
    'frilly',
    'frimaire',
    'fringe',
    'fringed',
    'fringepod',
    'fringes',
    'fringilla',
    'fringillidae',
    'fringy',
    'frippery',
    'frisbee',
    'frisch',
    'frisia',
    'frisian',
    'frisk',
    'frisked',
    'friskiness',
    'frisking',
    'frisky',
    'frisson',
    'fritillaria',
    'fritillaries',
    'fritillary',
    'frittata',
    'fritter',
    'fritters',
    'friuli',
    'friulian',
    'frivol',
    'frivolity',
    'frivolous',
    'frivolously',
    'frivolousness',
    'frizz',
    'frizzle',
    'frizzly',
    'frizzy',
    'fro',
    'frobisher',
    'frock',
    'froebel',
    'froelichia',
    'frog',
    'frogbit',
    'frogfish',
    'froghopper',
    'froghoppers',
    'frogman',
    'frogmarch',
    'frogmouth',
    'frogmouths',
    'frogs',
    'frolic',
    'frolicked',
    'frolicky',
    'frolics',
    'frolicsome',
    'frolicsomeness',
    'from',
    'frond',
    'fronds',
    'front',
    'frontage',
    'frontal',
    'frontbencher',
    'frontier',
    'frontiers',
    'frontiersman',
    'frontierswoman',
    'frontispiece',
    'frontlet',
    'frontmost',
    'fronts',
    'frontstall',
    'frore',
    'frost',
    'frostbite',
    'frostbitten',
    'frosted',
    'frostian',
    'frostiness',
    'frosting',
    'frosts',
    'frostweed',
    'frostwort',
    'frosty',
    'froth',
    'frothed',
    'frothiness',
    'frothing',
    'frothy',
    'frottage',
    'frotteur',
    'froward',
    'frown',
    'frowning',
    'frowsty',
    'frowsy',
    'frowzled',
    'frowzy',
    'froze',
    'frozen',
    'frs',
    'fructidor',
    'fructification',
    'fructify',
    'fructose',
    'fructosuria',
    'frugal',
    'frugality',
    'frugally',
    'frugalness',
    'fruit',
    'fruitage',
    'fruitcake',
    'fruited',
    'fruiterer',
    'fruitful',
    'fruitfulness',
    'fruiting',
    'fruition',
    'fruitless',
    'fruitlessness',
    'fruitlet',
    'fruitlets',
    'fruits',
    'fruitwood',
    'fruity',
    'frumenty',
    'frump',
    'frumpish',
    'frumpy',
    'frunze',
    'frustrate',
    'frustrated',
    'frustrates',
    'frustrating',
    'frustration',
    'frustrations',
    'frustrative',
    'frustum',
    'fruticose',
    'fruticulose',
    'fry',
    'frye',
    'fryer',
    'frying',
    'frypan',
    'fsb',
    'fsh',
    'ft',
    'ftc',
    'fthm',
    'fto',
    'ftp',
    'fu',
    'fucaceae',
    'fucales',
    'fuchs',
    'fuchsia',
    'fuck',
    'fucked',
    'fucker',
    'fuckhead',
    'fucking',
    'fuckup',
    'fucoid',
    'fucus',
    'fuddle',
    'fuddled',
    'fudge',
    'fuego',
    'fuel',
    'fueled',
    'fueling',
    'fuels',
    'fuentes',
    'fug',
    'fugacious',
    'fugaciousness',
    'fugacity',
    'fugal',
    'fugard',
    'fuggy',
    'fugitive',
    'fugitives',
    'fugleman',
    'fugly',
    'fugo',
    'fugu',
    'fugue',
    'fuji',
    'fujinoyama',
    'fujiyama',
    'fukien',
    'fukkianese',
    'fukuoka',
    'ful',
    'fula',
    'fulah',
    'fulani',
    'fulbe',
    'fulbright',
    'fulcrum',
    'fulfil',
    'fulfill',
    'fulfilled',
    'fulfilling',
    'fulfillment',
    'fulfills',
    'fulfilment',
    'fulgent',
    'fulgid',
    'fulgoridae',
    'fulgurant',
    'fulgurating',
    'fulgurous',
    'fulica',
    'full',
    'fullback',
    'fuller',
    'fullerene',
    'fullerenes',
    'fulling',
    'fullness',
    'fulls',
    'fully',
    'fulmar',
    'fulmars',
    'fulmarus',
    'fulminant',
    'fulminate',
    'fulminated',
    'fulmination',
    'fulminations',
    'fulminic',
    'fulsome',
    'fulsomeness',
    'fulton',
    'fulvic',
    'fulvicin',
    'fumaria',
    'fumariaceae',
    'fumble',
    'fumbled',
    'fumbler',
    'fumbling',
    'fume',
    'fumed',
    'fumeroot',
    'fumes',
    'fumewort',
    'fumigant',
    'fumigants',
    'fumigate',
    'fumigating',
    'fumigation',
    'fumigator',
    'fuming',
    'fumitory',
    'fun',
    'funafuti',
    'funambulism',
    'funambulist',
    'function',
    'functional',
    'functionalism',
    'functionalist',
    'functionality',
    'functionally',
    'functionary',
    'functioned',
    'functioning',
    'functions',
    'fund',
    'fundament',
    'fundamental',
    'fundamentalism',
    'fundamentalist',
    'fundamentalistic',
    'fundamentalists',
    'fundamentally',
    'fundamentals',
    'funded',
    'funding',
    'fundraise',
    'fundraiser',
    'fundraising',
    'funds',
    'fundulus',
    'fundus',
    'fundy',
    'funeral',
    'funerals',
    'funerary',
    'funereal',
    'funfair',
    'fungal',
    'fungi',
    'fungia',
    'fungibility',
    'fungible',
    'fungicidal',
    'fungicide',
    'fungicides',
    'fungoid',
    'fungous',
    'fungus',
    'funguslike',
    'funicle',
    'funicular',
    'funiculitis',
    'funiculus',
    'funk',
    'funka',
    'funkaceae',
    'funky',
    'funnel',
    'funnels',
    'funnies',
    'funniness',
    'funny',
    'funrun',
    'fuqra',
    'fur',
    'furan',
    'furane',
    'furbelow',
    'furbish',
    'furcate',
    'furcation',
    'furcula',
    'furfural',
    'furfuraldehyde',
    'furfuran',
    'furies',
    'furious',
    'furiously',
    'furiousness',
    'furl',
    'furled',
    'furlike',
    'furlong',
    'furlough',
    'furloughed',
    'furnace',
    'furnaces',
    'furnariidae',
    'furnarius',
    'furnish',
    'furnished',
    'furnishes',
    'furnishing',
    'furnishings',
    'furniture',
    'furnivall',
    'furor',
    'furore',
    'furosemide',
    'furred',
    'furrier',
    'furring',
    'furrow',
    'furrowed',
    'furrows',
    'furry',
    'furs',
    'further',
    'furtherance',
    'furthering',
    'furthermost',
    'furthers',
    'furthest',
    'furtive',
    'furtively',
    'furtiveness',
    'furuncle',
    'furuncles',
    'furunculosis',
    'fury',
    'furze',
    'fusain',
    'fusanus',
    'fusarium',
    'fuschia',
    'fuscoboletinus',
    'fuscous',
    'fuse',
    'fused',
    'fusee',
    'fuselage',
    'fuses',
    'fusible',
    'fusiform',
    'fusil',
    'fusilier',
    'fusillade',
    'fusing',
    'fusion',
    'fuss',
    'fussed',
    'fusses',
    'fussiness',
    'fusspot',
    'fussy',
    'fustian',
    'fustigate',
    'fusty',
    'futile',
    'futility',
    'futon',
    'future',
    'futureless',
    'futures',
    'futurism',
    'futurist',
    'futuristic',
    'futuristics',
    'futurity',
    'futurology',
    'fuze',
    'fuzee',
    'fuzz',
    'fuzzed',
    'fuzziness',
    'fuzzy',
    'fws']



from typing import List, Dict, Any
from dataclasses import dataclass, asdict


@dataclass
class OtherInfo:
    """
    Represents additional information associated with a token processed by Spacy.
    This includes both the token's own information and its relationship to the "head" token in dependency parsing.

    Attributes:
        i (int): The token's index in the sentence.
        idx (int): Duplicate of `i` for convenience, representing the token's index.
        orth (int): The orthographic representation of the token, typically used as a hash value.
        head_i (int): The index of the token's head in dependency parsing.
        head_idx (int): Duplicate of `head_i`, for consistency with token indexing attributes.
        head_orth (int): The orthographic representation (hash) of the head token.
        head_text (str): The textual representation of the head token.
    """
    i: int
    idx: int
    orth: int
    head_i: int
    head_idx: int
    head_orth: int
    head_text: str


@dataclass
class SpacyResult:
    """
    Represents a token parsed by a custom Spacy parser, encapsulating various linguistic features.

    Relationships:
        - Each SpacyResult contains exactly one OtherInfo instance, detailing further morphological and dependency information.

    Attributes:
        id (str): Unique identifier for the token.
        text (str): The actual text of the token.
        tense (str): The tense of the token, if applicable.
        noun_number (str): Singular or plural for nouns.
        verb_form (str): The form of the verb (e.g., base, past).
        sentiment (float): Sentiment score associated with the token.
        pos (str): Part of speech.
        tag (str): Detailed part-of-speech tag.
        dep (str): Syntactic dependency relation.
        ent (str): Named entity type, if any.
        shape (str): The shape representation of the token (e.g., "Xxxx" for capitalization).
        is_alpha (bool): Whether the token is alphabetic.
        is_stop (bool): Whether the token is a stop word.
        head (str): The textual representation of the token's syntactic head.
        other (OtherInfo): Additional information about the token.
        is_punct (bool): Whether the token is punctuation.
        x (int), y (int): Coordinates for graphical representation or spatial analysis.
        is_wordnet (bool): Whether the token is found in WordNet.
        normal (str): The normalized form of the token.
        stem (str): The stemmed version of the token.

    Methods:
        to_string: Returns a simplified string representation combining text and POS.
        is_noun: Determines if the token is a noun (common or proper).
        is_hyphen: Checks if the token is a hyphen.
    """
    id: str
    text: str
    tense: str
    noun_number: str
    verb_form: str
    sentiment: float
    pos: str
    tag: str
    dep: str
    ent: str
    shape: str
    is_alpha: bool
    is_stop: bool
    head: str
    other: OtherInfo
    is_punct: bool
    x: int
    y: int
    is_wordnet: bool
    normal: str
    stem: str

    def to_string(self) -> str:
        """Returns a simplified string representation combining text and POS."""
        text_pos = f"{self.text.strip()}/{self.pos.upper()}"
        if len(self.ent):
            return f"{text_pos}/{self.ent.upper()}"
        return text_pos

    def is_noun(self) -> bool:
        """Determines if the token is a noun (common or proper)."""
        return self.pos.upper() in ['NOUN', 'PROPN']

    def is_hyphen(self) -> bool:
        """Checks if the token is a hyphen."""
        return self.text.strip() == '-'

    def to_json(self) -> dict:
        return asdict(self)


def to_spacy_result(data: Dict[str, Any]) -> SpacyResult:
    other_info_data = data.pop('other')
    other_info = OtherInfo(**other_info_data)
    return SpacyResult(other=other_info, **data)


@dataclass
class Sentence:
    """
    Represents a sentence composed of multiple SpacyResult tokens.

    Relationships:
        - A Sentence consists of one or more SpacyResult instances, each representing a parsed token.

    Attributes:
        tokens (List[SpacyResult]): The list of tokens (SpacyResult instances) that make up the sentence.

    Methods:
        to_string: Returns a string representation of the sentence, showing each token's text and POS.
        sentence_text: Concatenates the text of all tokens into a single string representing the sentence.
        size: Returns the number of tokens in the sentence.
    """
    tokens: List[SpacyResult]

    def __post_init__(self):
        if not isinstance(self.tokens, list):
            raise TypeError(
                f"Tokens must be 'List[SpacyResult]', got {type(self.tokens)}")
        for token in self.tokens:
            if not isinstance(token, SpacyResult):
                raise TypeError(
                    f"All tokens must be of type 'SpacyResult', got {type(token)}")

    def __iter__(self):
        return iter(self.tokens)

    def to_string(self) -> str:
        """Returns a string representation of the sentence, showing each token's text and POS."""
        return ' '.join([token.to_string() for token in self.tokens])

    def sentence_text(self) -> str:
        """Concatenates the text of all tokens into a single string representing the sentence."""
        return ''.join([token.text for token in self.tokens])

    def size(self) -> int:
        """Returns the number of tokens in the sentence."""
        return len(self.tokens)

    def to_json(self) -> list:
        return [
            token.to_json() for token in self.tokens
        ]


@dataclass
class Sentences:
    """
    Represents a collection of Sentence instances, effectively modeling a paragraph or a collection of sentences.

    Relationships:
        - Consists of one or more Sentence instances, each representing a parsed sentence.

    Attributes:
        sentences (List[Sentence]): The list of Sentence instances in the collection.

    Methods:
        to_string: Returns a string representation of all sentences, separated by new lines.
        sentence_text: Concatenates the text of all sentences into a single string, with sentences separated by new lines.
        size: Returns the number of Sentence instances in the collection.
    """
    sentences: List[Sentence]

    def __post_init__(self):
        if not isinstance(self.sentences, list):
            raise TypeError(
                f"Tokens must be 'List[Sentence]', got {type(self.sentences)}")
        for sentence in self.sentences:
            if not isinstance(sentence, Sentence):
                raise TypeError(
                    f"All tokens must be of type 'Sentence', got {type(sentence)}")

    def __iter__(self):
        return iter(self.sentences)

    def to_string(self):
        """Returns a string representation of all sentences, separated by new lines."""
        return '\n\n'.join([sentence.to_string() for sentence in self.sentences])

    def sentence_text(self) -> str:
        """Concatenates the text of all sentences into a single string, with sentences separated by new lines."""
        return [
            sentence.sentence_text()
            for sentence in self.sentences
        ]

    def size(self) -> int:
        """Returns the number of Sentence instances in the collection."""
        return len(self.sentences)

    def to_json(self) -> list:
        return [
            sentence.to_json() for sentence in self.sentences
        ]


def transform_parse_results_to_sentences(parse_results: list) -> Sentences:
    """ Assumes that a prior instance of Sentences was persisted to file using <Sentences>.to_json()
    this will restore the json form to a Sentences instance
    """
    sentence_results = []
    for _sentence in parse_results:
        spacy_results = []
        for _token in _sentence:
            spacy_results.append(SpacyResult(**_token))
        sentence_results.append(Sentence(spacy_results))
    return Sentences(sentence_results)


@dataclass
class SentencePhrases:
    """
    Contains a Sentence instance and a list of phrases extracted from that sentence.

    Relationships:
        - Directly associated with one Sentence instance.

    Attributes:
        sentence (Sentence): The Sentence from which phrases are extracted.
        phrases (List[str]): The extracted phrases from the sentence.
    """
    sentence: Sentence
    phrases: List[str]

    def __post_init__(self):
        if not isinstance(self.sentence, Sentence):
            raise TypeError(
                f"Tokens must be 'Sentence', got {type(self.sentence)}")
        if not isinstance(self.phrases, list):
            raise TypeError(
                f"Tokens must be 'List[str]', got {type(self.phrases)}")
        for phrase in self.phrases:
            if not isinstance(phrase, str):
                raise TypeError(
                    f"All phrases must be of type 'str', got {type(phrase)}")
